/* ScheduledStatus.c generated by valac 0.56.19, the Vala compiler
 * generated from ScheduledStatus.vala, do not modify */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>
#include <adwaita.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <libsoup/soup.h>
#include <json-glib/json-glib.h>
#include <pango/pango.h>

#define TUBA_API_SCHEDULED_STATUS_DRAFT_YEAR (2000 + 3000)
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_WIDGETS_TYPE_SCHEDULED_STATUS (tuba_widgets_scheduled_status_get_type ())
#define TUBA_WIDGETS_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatus))
#define TUBA_WIDGETS_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatusClass))
#define TUBA_WIDGETS_IS_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS))
#define TUBA_WIDGETS_IS_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS))
#define TUBA_WIDGETS_SCHEDULED_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatusClass))

typedef struct _TubaWidgetsScheduledStatus TubaWidgetsScheduledStatus;
typedef struct _TubaWidgetsScheduledStatusClass TubaWidgetsScheduledStatusClass;
typedef struct _TubaWidgetsScheduledStatusPrivate TubaWidgetsScheduledStatusPrivate;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_SCHEDULED_STATUS (tuba_api_scheduled_status_get_type ())
#define TUBA_API_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatus))
#define TUBA_API_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatusClass))
#define TUBA_API_IS_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_SCHEDULED_STATUS))
#define TUBA_API_IS_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_SCHEDULED_STATUS))
#define TUBA_API_SCHEDULED_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatusClass))

typedef struct _TubaAPIScheduledStatus TubaAPIScheduledStatus;
typedef struct _TubaAPIScheduledStatusClass TubaAPIScheduledStatusClass;

#define TUBA_WIDGETS_TYPE_STATUS (tuba_widgets_status_get_type ())
#define TUBA_WIDGETS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatus))
#define TUBA_WIDGETS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatusClass))
#define TUBA_WIDGETS_IS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_STATUS))
#define TUBA_WIDGETS_IS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_STATUS))
#define TUBA_WIDGETS_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatusClass))

typedef struct _TubaWidgetsStatus TubaWidgetsStatus;
typedef struct _TubaWidgetsStatusClass TubaWidgetsStatusClass;

#define TUBA_API_TYPE_POLL (tuba_api_poll_get_type ())
#define TUBA_API_POLL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_POLL, TubaAPIPoll))
#define TUBA_API_POLL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_POLL, TubaAPIPollClass))
#define TUBA_API_IS_POLL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_POLL))
#define TUBA_API_IS_POLL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_POLL))
#define TUBA_API_POLL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_POLL, TubaAPIPollClass))

typedef struct _TubaAPIPoll TubaAPIPoll;
typedef struct _TubaAPIPollClass TubaAPIPollClass;
enum  {
	TUBA_WIDGETS_SCHEDULED_STATUS_0_PROPERTY,
	TUBA_WIDGETS_SCHEDULED_STATUS_DRAFT_PROPERTY,
	TUBA_WIDGETS_SCHEDULED_STATUS_IS_INLINE_PROPERTY,
	TUBA_WIDGETS_SCHEDULED_STATUS_NUM_PROPERTIES
};
static GParamSpec* tuba_widgets_scheduled_status_properties[TUBA_WIDGETS_SCHEDULED_STATUS_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS (tuba_api_scheduled_status_params_get_type ())
#define TUBA_API_SCHEDULED_STATUS_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS, TubaAPIScheduledStatusParams))
#define TUBA_API_SCHEDULED_STATUS_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS, TubaAPIScheduledStatusParamsClass))
#define TUBA_API_SCHEDULED_STATUS_IS_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS))
#define TUBA_API_SCHEDULED_STATUS_IS_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS))
#define TUBA_API_SCHEDULED_STATUS_PARAMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS, TubaAPIScheduledStatusParamsClass))

typedef struct _TubaAPIScheduledStatusParams TubaAPIScheduledStatusParams;
typedef struct _TubaAPIScheduledStatusParamsClass TubaAPIScheduledStatusParamsClass;

#define TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL (tuba_api_scheduled_status_params_poll_get_type ())
#define TUBA_API_SCHEDULED_STATUS_PARAMS_POLL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL, TubaAPIScheduledStatusParamsPoll))
#define TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL, TubaAPIScheduledStatusParamsPollClass))
#define TUBA_API_SCHEDULED_STATUS_PARAMS_IS_POLL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL))
#define TUBA_API_SCHEDULED_STATUS_PARAMS_IS_POLL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL))
#define TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL, TubaAPIScheduledStatusParamsPollClass))

typedef struct _TubaAPIScheduledStatusParamsPoll TubaAPIScheduledStatusParamsPoll;
typedef struct _TubaAPIScheduledStatusParamsPollClass TubaAPIScheduledStatusParamsPollClass;

#define TUBA_API_TYPE_POLL_OPTION (tuba_api_poll_option_get_type ())
#define TUBA_API_POLL_OPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_POLL_OPTION, TubaAPIPollOption))
#define TUBA_API_POLL_OPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_POLL_OPTION, TubaAPIPollOptionClass))
#define TUBA_API_IS_POLL_OPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_POLL_OPTION))
#define TUBA_API_IS_POLL_OPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_POLL_OPTION))
#define TUBA_API_POLL_OPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_POLL_OPTION, TubaAPIPollOptionClass))

typedef struct _TubaAPIPollOption TubaAPIPollOption;
typedef struct _TubaAPIPollOptionClass TubaAPIPollOptionClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

#define TUBA_API_TYPE_STATUS (tuba_api_status_get_type ())
#define TUBA_API_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_STATUS, TubaAPIStatus))
#define TUBA_API_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_STATUS, TubaAPIStatusClass))
#define TUBA_API_IS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_STATUS))
#define TUBA_API_IS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_STATUS))
#define TUBA_API_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_STATUS, TubaAPIStatusClass))

typedef struct _TubaAPIStatus TubaAPIStatus;
typedef struct _TubaAPIStatusClass TubaAPIStatusClass;

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_API_TYPE_ATTACHMENT (tuba_api_attachment_get_type ())
#define TUBA_API_ATTACHMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ATTACHMENT, TubaAPIAttachment))
#define TUBA_API_ATTACHMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ATTACHMENT, TubaAPIAttachmentClass))
#define TUBA_API_IS_ATTACHMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ATTACHMENT))
#define TUBA_API_IS_ATTACHMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ATTACHMENT))
#define TUBA_API_ATTACHMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ATTACHMENT, TubaAPIAttachmentClass))

typedef struct _TubaAPIAttachment TubaAPIAttachment;
typedef struct _TubaAPIAttachmentClass TubaAPIAttachmentClass;
typedef struct _TubaWidgetsStatusPrivate TubaWidgetsStatusPrivate;
typedef void (*TubaDialogsComposerDialogSuccessCallback) (TubaAPIStatus* cb_status, gpointer user_data);

#define TUBA_WIDGETS_TYPE_RICH_LABEL (tuba_widgets_rich_label_get_type ())
#define TUBA_WIDGETS_RICH_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_RICH_LABEL, TubaWidgetsRichLabel))
#define TUBA_WIDGETS_RICH_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_RICH_LABEL, TubaWidgetsRichLabelClass))
#define TUBA_WIDGETS_IS_RICH_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_RICH_LABEL))
#define TUBA_WIDGETS_IS_RICH_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_RICH_LABEL))
#define TUBA_WIDGETS_RICH_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_RICH_LABEL, TubaWidgetsRichLabelClass))

typedef struct _TubaWidgetsRichLabel TubaWidgetsRichLabel;
typedef struct _TubaWidgetsRichLabelClass TubaWidgetsRichLabelClass;

#define TUBA_WIDGETS_TYPE_AVATAR (tuba_widgets_avatar_get_type ())
#define TUBA_WIDGETS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatar))
#define TUBA_WIDGETS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatarClass))
#define TUBA_WIDGETS_IS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_AVATAR))
#define TUBA_WIDGETS_IS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_AVATAR))
#define TUBA_WIDGETS_AVATAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatarClass))

typedef struct _TubaWidgetsAvatar TubaWidgetsAvatar;
typedef struct _TubaWidgetsAvatarClass TubaWidgetsAvatarClass;

#define TUBA_WIDGETS_TYPE_MARKUP_VIEW (tuba_widgets_markup_view_get_type ())
#define TUBA_WIDGETS_MARKUP_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupView))
#define TUBA_WIDGETS_MARKUP_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupViewClass))
#define TUBA_WIDGETS_IS_MARKUP_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW))
#define TUBA_WIDGETS_IS_MARKUP_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_MARKUP_VIEW))
#define TUBA_WIDGETS_MARKUP_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupViewClass))

typedef struct _TubaWidgetsMarkupView TubaWidgetsMarkupView;
typedef struct _TubaWidgetsMarkupViewClass TubaWidgetsMarkupViewClass;

#define TUBA_WIDGETS_TYPE_FADE_BIN (tuba_widgets_fade_bin_get_type ())
#define TUBA_WIDGETS_FADE_BIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_FADE_BIN, TubaWidgetsFadeBin))
#define TUBA_WIDGETS_FADE_BIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_FADE_BIN, TubaWidgetsFadeBinClass))
#define TUBA_WIDGETS_IS_FADE_BIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_FADE_BIN))
#define TUBA_WIDGETS_IS_FADE_BIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_FADE_BIN))
#define TUBA_WIDGETS_FADE_BIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_FADE_BIN, TubaWidgetsFadeBinClass))

typedef struct _TubaWidgetsFadeBin TubaWidgetsFadeBin;
typedef struct _TubaWidgetsFadeBinClass TubaWidgetsFadeBinClass;

#define TUBA_WIDGETS_TYPE_PREVIEW_CARD (tuba_widgets_preview_card_get_type ())
#define TUBA_WIDGETS_PREVIEW_CARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_PREVIEW_CARD, TubaWidgetsPreviewCard))
#define TUBA_WIDGETS_PREVIEW_CARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_PREVIEW_CARD, TubaWidgetsPreviewCardClass))
#define TUBA_WIDGETS_IS_PREVIEW_CARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_PREVIEW_CARD))
#define TUBA_WIDGETS_IS_PREVIEW_CARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_PREVIEW_CARD))
#define TUBA_WIDGETS_PREVIEW_CARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_PREVIEW_CARD, TubaWidgetsPreviewCardClass))

typedef struct _TubaWidgetsPreviewCard TubaWidgetsPreviewCard;
typedef struct _TubaWidgetsPreviewCardClass TubaWidgetsPreviewCardClass;

#define TUBA_WIDGETS_TYPE_VOTE_BOX (tuba_widgets_vote_box_get_type ())
#define TUBA_WIDGETS_VOTE_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_VOTE_BOX, TubaWidgetsVoteBox))
#define TUBA_WIDGETS_VOTE_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_VOTE_BOX, TubaWidgetsVoteBoxClass))
#define TUBA_WIDGETS_IS_VOTE_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_VOTE_BOX))
#define TUBA_WIDGETS_IS_VOTE_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_VOTE_BOX))
#define TUBA_WIDGETS_VOTE_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_VOTE_BOX, TubaWidgetsVoteBoxClass))

typedef struct _TubaWidgetsVoteBox TubaWidgetsVoteBox;
typedef struct _TubaWidgetsVoteBoxClass TubaWidgetsVoteBoxClass;
typedef struct _TubaWidgetsVoteBoxPrivate TubaWidgetsVoteBoxPrivate;
#define _g_time_zone_unref0(var) ((var == NULL) ? NULL : (var = (g_time_zone_unref (var), NULL)))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))

#define TUBA_WIDGETS_SCHEDULED_STATUS_TYPE_RESCHEDULE_DIALOG (tuba_widgets_scheduled_status_reschedule_dialog_get_type ())
#define TUBA_WIDGETS_SCHEDULED_STATUS_RESCHEDULE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_SCHEDULED_STATUS_TYPE_RESCHEDULE_DIALOG, TubaWidgetsScheduledStatusRescheduleDialog))
#define TUBA_WIDGETS_SCHEDULED_STATUS_RESCHEDULE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_SCHEDULED_STATUS_TYPE_RESCHEDULE_DIALOG, TubaWidgetsScheduledStatusRescheduleDialogClass))
#define TUBA_WIDGETS_SCHEDULED_STATUS_IS_RESCHEDULE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_SCHEDULED_STATUS_TYPE_RESCHEDULE_DIALOG))
#define TUBA_WIDGETS_SCHEDULED_STATUS_IS_RESCHEDULE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_SCHEDULED_STATUS_TYPE_RESCHEDULE_DIALOG))
#define TUBA_WIDGETS_SCHEDULED_STATUS_RESCHEDULE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_SCHEDULED_STATUS_TYPE_RESCHEDULE_DIALOG, TubaWidgetsScheduledStatusRescheduleDialogClass))

typedef struct _TubaWidgetsScheduledStatusRescheduleDialog TubaWidgetsScheduledStatusRescheduleDialog;
typedef struct _TubaWidgetsScheduledStatusRescheduleDialogClass TubaWidgetsScheduledStatusRescheduleDialogClass;

#define TUBA_TYPE_APPLICATION (tuba_application_get_type ())
#define TUBA_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_APPLICATION, TubaApplication))
#define TUBA_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_APPLICATION, TubaApplicationClass))
#define TUBA_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_APPLICATION))
#define TUBA_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_APPLICATION))
#define TUBA_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_APPLICATION, TubaApplicationClass))

typedef struct _TubaApplication TubaApplication;
typedef struct _TubaApplicationClass TubaApplicationClass;

#define TUBA_DIALOGS_TYPE_MAIN_WINDOW (tuba_dialogs_main_window_get_type ())
#define TUBA_DIALOGS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindow))
#define TUBA_DIALOGS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))
#define TUBA_DIALOGS_IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))

typedef struct _TubaDialogsMainWindow TubaDialogsMainWindow;
typedef struct _TubaDialogsMainWindowClass TubaDialogsMainWindowClass;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;
typedef enum  {
	TUBA_REQUEST_V2_METHOD_GET,
	TUBA_REQUEST_V2_METHOD_POST,
	TUBA_REQUEST_V2_METHOD_PUT,
	TUBA_REQUEST_V2_METHOD_DELETE,
	TUBA_REQUEST_V2_METHOD_PATCH
} TubaRequestV2Method;

#define TUBA_REQUEST_V2_TYPE_METHOD (tuba_request_v2_method_get_type ())

#define TUBA_TYPE_OOPSIE (tuba_oopsie_get_type ())

#define TUBA_TYPE_NETWORK (tuba_network_get_type ())
#define TUBA_NETWORK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_NETWORK, TubaNetwork))
#define TUBA_NETWORK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_NETWORK, TubaNetworkClass))
#define TUBA_IS_NETWORK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_NETWORK))
#define TUBA_IS_NETWORK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_NETWORK))
#define TUBA_NETWORK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_NETWORK, TubaNetworkClass))

typedef struct _TubaNetwork TubaNetwork;
typedef struct _TubaNetworkClass TubaNetworkClass;
#define __vala_JsonNode_free0(var) ((var == NULL) ? NULL : (var = (_vala_JsonNode_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _TubaWidgetsScheduledStatusOnSchedulePickedRealData TubaWidgetsScheduledStatusOnSchedulePickedRealData;

#define TUBA_APPLICATION_TYPE_QUESTION_TEXT (tuba_application_question_text_get_type ())
typedef struct _TubaApplicationQuestionText TubaApplicationQuestionText;

#define TUBA_APPLICATION_TYPE_QUESTION_BUTTONS (tuba_application_question_buttons_get_type ())
typedef struct _TubaApplicationQuestionButtons TubaApplicationQuestionButtons;

#define TUBA_APPLICATION_TYPE_QUESTION_BUTTON (tuba_application_question_button_get_type ())
typedef struct _TubaApplicationQuestionButton TubaApplicationQuestionButton;
typedef enum  {
	TUBA_APPLICATION_QUESTION_ANSWER_YES,
	TUBA_APPLICATION_QUESTION_ANSWER_NO,
	TUBA_APPLICATION_QUESTION_ANSWER_CLOSE
} TubaApplicationQuestionAnswer;

#define TUBA_APPLICATION_TYPE_QUESTION_ANSWER (tuba_application_question_answer_get_type ())
typedef struct _TubaWidgetsScheduledStatusDeleteStatusData TubaWidgetsScheduledStatusDeleteStatusData;

#define TUBA_DIALOGS_COMPOSER_TYPE_DIALOG (tuba_dialogs_composer_dialog_get_type ())
#define TUBA_DIALOGS_COMPOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_COMPOSER_TYPE_DIALOG, TubaDialogsComposerDialog))
#define TUBA_DIALOGS_COMPOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_COMPOSER_TYPE_DIALOG, TubaDialogsComposerDialogClass))
#define TUBA_DIALOGS_COMPOSER_IS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_COMPOSER_TYPE_DIALOG))
#define TUBA_DIALOGS_COMPOSER_IS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_COMPOSER_TYPE_DIALOG))
#define TUBA_DIALOGS_COMPOSER_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_COMPOSER_TYPE_DIALOG, TubaDialogsComposerDialogClass))

typedef struct _TubaDialogsComposerDialog TubaDialogsComposerDialog;
typedef struct _TubaDialogsComposerDialogClass TubaDialogsComposerDialogClass;
typedef struct _TubaWidgetsScheduledStatusRescheduleDialogPrivate TubaWidgetsScheduledStatusRescheduleDialogPrivate;
enum  {
	TUBA_WIDGETS_SCHEDULED_STATUS_RESCHEDULE_DIALOG_0_PROPERTY,
	TUBA_WIDGETS_SCHEDULED_STATUS_RESCHEDULE_DIALOG_NUM_PROPERTIES
};
static GParamSpec* tuba_widgets_scheduled_status_reschedule_dialog_properties[TUBA_WIDGETS_SCHEDULED_STATUS_RESCHEDULE_DIALOG_NUM_PROPERTIES];

#define TUBA_DIALOGS_TYPE_SCHEDULE (tuba_dialogs_schedule_get_type ())
#define TUBA_DIALOGS_SCHEDULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_SCHEDULE, TubaDialogsSchedule))
#define TUBA_DIALOGS_SCHEDULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_SCHEDULE, TubaDialogsScheduleClass))
#define TUBA_DIALOGS_IS_SCHEDULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_SCHEDULE))
#define TUBA_DIALOGS_IS_SCHEDULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_SCHEDULE))
#define TUBA_DIALOGS_SCHEDULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_SCHEDULE, TubaDialogsScheduleClass))

typedef struct _TubaDialogsSchedule TubaDialogsSchedule;
typedef struct _TubaDialogsScheduleClass TubaDialogsScheduleClass;
enum  {
	TUBA_WIDGETS_SCHEDULED_STATUS_RESCHEDULE_DIALOG_SCHEDULE_PICKED_SIGNAL,
	TUBA_WIDGETS_SCHEDULED_STATUS_RESCHEDULE_DIALOG_NUM_SIGNALS
};
static guint tuba_widgets_scheduled_status_reschedule_dialog_signals[TUBA_WIDGETS_SCHEDULED_STATUS_RESCHEDULE_DIALOG_NUM_SIGNALS] = {0};
enum  {
	TUBA_WIDGETS_SCHEDULED_STATUS_DELETED_SIGNAL,
	TUBA_WIDGETS_SCHEDULED_STATUS_REFRESH_SIGNAL,
	TUBA_WIDGETS_SCHEDULED_STATUS_OPEN_SIGNAL,
	TUBA_WIDGETS_SCHEDULED_STATUS_INLINE_CLICKED_SIGNAL,
	TUBA_WIDGETS_SCHEDULED_STATUS_NUM_SIGNALS
};
static guint tuba_widgets_scheduled_status_signals[TUBA_WIDGETS_SCHEDULED_STATUS_NUM_SIGNALS] = {0};

struct _TubaWidgetsScheduledStatus {
	GtkListBoxRow parent_instance;
	TubaWidgetsScheduledStatusPrivate * priv;
};

struct _TubaWidgetsScheduledStatusClass {
	GtkListBoxRowClass parent_class;
};

struct _TubaWidgetsScheduledStatusPrivate {
	gboolean _draft;
	gboolean _is_inline;
	GtkButton* reschedule_button;
	GtkButton* to_draft_button;
	GtkButton* edit_button;
	GtkBox* content_box;
	GtkLabel* schedule_label;
	GtkBox* action_box;
	GtkSeparator* separator;
	TubaAPIScheduledStatus* bound_scheduled_status;
	TubaWidgetsStatus* status_widget;
	TubaAPIPoll* status_poll;
};

struct _TubaWidgetsStatus {
	GtkListBoxRow parent_instance;
	TubaWidgetsStatusPrivate * priv;
	TubaDialogsComposerDialogSuccessCallback reply_cb;
	gpointer reply_cb_target;
	GDestroyNotify reply_cb_target_destroy_notify;
	GtkBox* status_box;
	GtkBox* avatar_side;
	GtkBox* title_box;
	GtkBox* content_side;
	AdwWrapBox* name_wrapbox;
	GtkMenuButton* menu_button;
	GtkImage* header_icon;
	TubaWidgetsRichLabel* header_label;
	GtkButton* header_button;
	TubaWidgetsAvatar* avatar;
	GtkOverlay* avatar_overlay;
	GtkButton* name_button;
	TubaWidgetsRichLabel* name_label;
	GtkLabel* handle_label;
	GtkBox* indicators;
	GtkLabel* date_label;
	GtkImage* pin_indicator;
	GtkImage* edited_indicator;
	GtkImage* visibility_indicator;
	GtkBox* content_column;
	GtkStack* spoiler_stack;
	GtkBox* content_box;
	TubaWidgetsMarkupView* content;
	GtkButton* spoiler_button;
	GtkLabel* spoiler_label;
	GtkLabel* spoiler_label_rev;
	GtkBox* spoiler_status_con;
	TubaWidgetsFadeBin* fade_bin;
	GtkStack* filter_stack;
	GtkLabel* filter_label;
	GtkLabel* filter_author_label;
	TubaWidgetsPreviewCard* prev_card;
	TubaWidgetsVoteBox* poll;
};

struct _TubaWidgetsStatusClass {
	GtkListBoxRowClass parent_class;
	void (*on_open) (TubaWidgetsStatus* self);
	void (*change_kind) (TubaWidgetsStatus* self);
	void (*bind) (TubaWidgetsStatus* self);
};

struct _TubaWidgetsVoteBox {
	GtkBox parent_instance;
	TubaWidgetsVoteBoxPrivate * priv;
	GtkListBox* poll_box;
	GtkButton* button_vote;
	GtkButton* button_refresh;
	GtkButton* button_results;
	GtkLabel* info_label;
	GeeArrayList* selected_index;
};

struct _TubaWidgetsVoteBoxClass {
	GtkBoxClass parent_class;
};

typedef enum  {
	TUBA_OOPSIE_USER,
	TUBA_OOPSIE_PARSING,
	TUBA_OOPSIE_INSTANCE,
	TUBA_OOPSIE_INTERNAL,
	TUBA_OOPSIE_HTTP_401 = 401,
	TUBA_OOPSIE_HTTP_403 = 403,
	TUBA_OOPSIE_HTTP_404 = 404,
	TUBA_OOPSIE_HTTP_410 = 410,
	TUBA_OOPSIE_HTTP_422 = 422,
	TUBA_OOPSIE_HTTP_429 = 429,
	TUBA_OOPSIE_HTTP_500 = 500,
	TUBA_OOPSIE_HTTP_503 = 503
} TubaOopsie;
#define TUBA_OOPSIE tuba_oopsie_quark ()

struct _TubaWidgetsScheduledStatusOnSchedulePickedRealData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaWidgetsScheduledStatus* self;
	gchar* iso8601;
	TubaRequestV2* req;
	TubaAPIScheduledStatus* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	TubaAccountStore* _tmp6_;
	TubaInstanceAccount* _tmp7_;
	TubaInstanceAccount* _tmp8_;
	TubaInstanceAccount* _tmp9_;
	TubaRequestV2* _tmp10_;
	TubaRequestV2* _tmp11_;
	TubaRequestV2* _tmp12_;
	GInputStream* in_stream;
	TubaRequestV2* _tmp13_;
	GInputStream* _tmp14_;
	JsonParser* parser;
	GInputStream* _tmp15_;
	JsonParser* _tmp16_;
	JsonNode* node;
	TubaNetwork* _tmp17_;
	JsonParser* _tmp18_;
	JsonNode* _tmp19_;
	TubaEntity* e;
	JsonNode* _tmp20_;
	JsonNode* _tmp21_;
	TubaEntity* _tmp22_;
	TubaEntity* _tmp23_;
	TubaEntity* _tmp24_;
	const gchar* _tmp25_;
	const gchar* _tmp26_;
	GDateTime* _tmp27_;
	GDateTime* _tmp28_;
	gboolean _tmp29_;
	TubaAPIScheduledStatus* _tmp30_;
	const gchar* _tmp31_;
	const gchar* _tmp32_;
	TubaEntity* _tmp33_;
	GError* _vala1_e;
	GError* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	GError* _tmp37_;
	const gchar* _tmp38_;
	const gchar* _tmp39_;
	gchar* _tmp40_;
	gchar* _tmp41_;
	TubaApplication* _tmp42_;
	GError* _tmp43_;
	const gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	GError* _inner_error0_;
};

struct _TubaApplicationQuestionText {
	gchar* text;
	gboolean use_markup;
};

struct _TubaApplicationQuestionButton {
	gchar* label;
	AdwResponseAppearance appearance;
};

struct _TubaApplicationQuestionButtons {
	TubaApplicationQuestionButton yes;
	TubaApplicationQuestionButton no;
};

struct _TubaWidgetsScheduledStatusDeleteStatusData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaWidgetsScheduledStatus* self;
	TubaRequestV2* req;
	TubaAPIScheduledStatus* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	TubaAccountStore* _tmp6_;
	TubaInstanceAccount* _tmp7_;
	TubaInstanceAccount* _tmp8_;
	TubaInstanceAccount* _tmp9_;
	TubaRequestV2* _tmp10_;
	TubaRequestV2* _tmp11_;
	GInputStream* _tmp12_;
	GInputStream* _tmp13_;
	TubaAPIScheduledStatus* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	gboolean _tmp17_;
	gboolean _tmp18_;
	TubaApplication* _tmp19_;
	GError* e;
	GError* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	GError* _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	TubaApplication* _tmp28_;
	GError* _tmp29_;
	const gchar* _tmp30_;
	GError* _inner_error0_;
};

struct _TubaWidgetsScheduledStatusRescheduleDialog {
	AdwDialog parent_instance;
	TubaWidgetsScheduledStatusRescheduleDialogPrivate * priv;
};

struct _TubaWidgetsScheduledStatusRescheduleDialogClass {
	AdwDialogClass parent_class;
};

static gint TubaWidgetsScheduledStatus_private_offset;
static gpointer tuba_widgets_scheduled_status_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;
VALA_EXTERN TubaApplication* tuba_app;
VALA_EXTERN TubaNetwork* tuba_network;
static gpointer tuba_widgets_scheduled_status_reschedule_dialog_parent_class = NULL;

VALA_EXTERN GType tuba_widgets_scheduled_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsScheduledStatus, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_scheduled_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIScheduledStatus, g_object_unref)
VALA_EXTERN GType tuba_widgets_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsStatus, g_object_unref)
VALA_EXTERN GType tuba_api_poll_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIPoll, g_object_unref)
VALA_EXTERN TubaWidgetsScheduledStatus* tuba_widgets_scheduled_status_new (TubaAPIScheduledStatus* scheduled_status);
VALA_EXTERN TubaWidgetsScheduledStatus* tuba_widgets_scheduled_status_construct (GType object_type,
                                                                     TubaAPIScheduledStatus* scheduled_status);
VALA_EXTERN void tuba_widgets_scheduled_status_bind (TubaWidgetsScheduledStatus* self,
                                         TubaAPIScheduledStatus* scheduled_status);
VALA_EXTERN GType tuba_api_scheduled_status_params_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIScheduledStatusParams, g_object_unref)
VALA_EXTERN TubaAPIScheduledStatusParams* tuba_api_scheduled_status_get_props (TubaAPIScheduledStatus* self);
VALA_EXTERN GType tuba_api_scheduled_status_params_poll_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIScheduledStatusParamsPoll, g_object_unref)
VALA_EXTERN TubaAPIScheduledStatusParamsPoll* tuba_api_scheduled_status_params_get_poll (TubaAPIScheduledStatusParams* self);
VALA_EXTERN gboolean tuba_api_scheduled_status_params_poll_get_multiple (TubaAPIScheduledStatusParamsPoll* self);
VALA_EXTERN GType tuba_api_poll_option_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIPollOption, g_object_unref)
VALA_EXTERN TubaAPIPoll* tuba_api_poll_new (const gchar* _id);
VALA_EXTERN TubaAPIPoll* tuba_api_poll_construct (GType object_type,
                                      const gchar* _id);
VALA_EXTERN void tuba_api_poll_set_multiple (TubaAPIPoll* self,
                                 gboolean value);
VALA_EXTERN void tuba_api_poll_set_options (TubaAPIPoll* self,
                                GeeArrayList* value);
VALA_EXTERN GeeArrayList* tuba_api_scheduled_status_params_poll_get_options (TubaAPIScheduledStatusParamsPoll* self);
VALA_EXTERN GeeArrayList* tuba_api_poll_get_options (TubaAPIPoll* self);
VALA_EXTERN TubaAPIPollOption* tuba_api_poll_option_new (void);
VALA_EXTERN TubaAPIPollOption* tuba_api_poll_option_construct (GType object_type);
VALA_EXTERN void tuba_api_poll_option_set_title (TubaAPIPollOption* self,
                                     const gchar* value);
VALA_EXTERN void tuba_api_poll_option_set_votes_count (TubaAPIPollOption* self,
                                           gint64 value);
VALA_EXTERN gint64 tuba_api_scheduled_status_params_poll_get_expires_in (TubaAPIScheduledStatusParamsPoll* self);
VALA_EXTERN void tuba_api_poll_set_expires_at (TubaAPIPoll* self,
                                   const gchar* value);
VALA_EXTERN GType tuba_api_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIStatus, g_object_unref)
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN const gchar* tuba_api_scheduled_status_params_get_spoiler_text (TubaAPIScheduledStatusParams* self);
VALA_EXTERN const gchar* tuba_api_scheduled_status_params_get_text (TubaAPIScheduledStatusParams* self);
VALA_EXTERN gboolean tuba_api_scheduled_status_params_get_sensitive (TubaAPIScheduledStatusParams* self);
VALA_EXTERN const gchar* tuba_api_scheduled_status_params_get_visibility (TubaAPIScheduledStatusParams* self);
VALA_EXTERN GType tuba_api_attachment_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAttachment, g_object_unref)
VALA_EXTERN GeeArrayList* tuba_api_scheduled_status_get_media_attachments (TubaAPIScheduledStatus* self);
VALA_EXTERN const gchar* tuba_api_scheduled_status_get_scheduled_at (TubaAPIScheduledStatus* self);
VALA_EXTERN TubaAPIStatus* tuba_api_status_new_empty (void);
VALA_EXTERN TubaAPIStatus* tuba_api_status_construct_empty (GType object_type);
VALA_EXTERN void tuba_api_status_set_account (TubaAPIStatus* self,
                                  TubaAPIAccount* value);
VALA_EXTERN void tuba_api_status_set_spoiler_text (TubaAPIStatus* self,
                                       const gchar* value);
VALA_EXTERN void tuba_api_status_set_content (TubaAPIStatus* self,
                                  const gchar* value);
VALA_EXTERN void tuba_api_status_set_sensitive (TubaAPIStatus* self,
                                    gboolean value);
VALA_EXTERN void tuba_api_status_set_visibility (TubaAPIStatus* self,
                                     const gchar* value);
VALA_EXTERN void tuba_api_status_set_media_attachments (TubaAPIStatus* self,
                                            GeeArrayList* value);
VALA_EXTERN void tuba_api_status_set_tuba_spoiler_revealed (TubaAPIStatus* self,
                                                gboolean value);
VALA_EXTERN void tuba_api_status_set_poll (TubaAPIStatus* self,
                               TubaAPIPoll* value);
VALA_EXTERN void tuba_api_status_set_created_at (TubaAPIStatus* self,
                                     const gchar* value);
VALA_EXTERN const gchar* tuba_api_scheduled_status_params_get_language (TubaAPIScheduledStatusParams* self);
VALA_EXTERN void tuba_api_status_set_language (TubaAPIStatus* self,
                                   const gchar* value);
VALA_EXTERN TubaWidgetsStatus* tuba_widgets_status_new (TubaAPIStatus* status);
VALA_EXTERN TubaWidgetsStatus* tuba_widgets_status_construct (GType object_type,
                                                  TubaAPIStatus* status);
VALA_EXTERN void tuba_widgets_status_set_can_be_opened (TubaWidgetsStatus* self,
                                            gboolean value);
VALA_EXTERN void tuba_widgets_status_toggle_actions_visibility (TubaWidgetsStatus* self,
                                                    gboolean visible);
VALA_EXTERN GType tuba_widgets_rich_label_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsRichLabel, g_object_unref)
VALA_EXTERN GType tuba_widgets_avatar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAvatar, g_object_unref)
VALA_EXTERN GType tuba_widgets_markup_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsMarkupView, g_object_unref)
VALA_EXTERN GType tuba_widgets_fade_bin_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsFadeBin, g_object_unref)
VALA_EXTERN GType tuba_widgets_preview_card_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsPreviewCard, g_object_unref)
VALA_EXTERN GType tuba_widgets_vote_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsVoteBox, g_object_unref)
VALA_EXTERN void tuba_widgets_vote_box_set_usable (TubaWidgetsVoteBox* self,
                                       gboolean value);
VALA_EXTERN gchar* tuba_utils_date_time_humanize_ago (const gchar* iso8601);
VALA_EXTERN const gchar* tuba_api_poll_get_expires_at (TubaAPIPoll* self);
static void tuba_widgets_scheduled_status_on_convert_to_draft (TubaWidgetsScheduledStatus* self);
static void tuba_widgets_scheduled_status_on_schedule_picked (TubaWidgetsScheduledStatus* self,
                                                       const gchar* iso8601);
static void tuba_widgets_scheduled_status_on_reschedule (TubaWidgetsScheduledStatus* self);
static GType tuba_widgets_scheduled_status_reschedule_dialog_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsScheduledStatusRescheduleDialog, g_object_unref)
static TubaWidgetsScheduledStatusRescheduleDialog* tuba_widgets_scheduled_status_reschedule_dialog_new (const gchar* iso8601);
static TubaWidgetsScheduledStatusRescheduleDialog* tuba_widgets_scheduled_status_reschedule_dialog_construct (GType object_type,
                                                                                                       const gchar* iso8601);
static void _tuba_widgets_scheduled_status_on_schedule_picked_tuba_widgets_scheduled_status_reschedule_dialog_schedule_picked (TubaWidgetsScheduledStatusRescheduleDialog* _sender,
                                                                                                                        const gchar* iso8601,
                                                                                                                        gpointer self);
VALA_EXTERN GType tuba_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaApplication, g_object_unref)
VALA_EXTERN GType tuba_dialogs_main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsMainWindow, g_object_unref)
VALA_EXTERN TubaDialogsMainWindow* tuba_application_get_main_window (TubaApplication* self);
static void tuba_widgets_scheduled_status_on_schedule_picked_real (TubaWidgetsScheduledStatus* self,
                                                            const gchar* iso8601,
                                                            GAsyncReadyCallback _callback_,
                                                            gpointer _user_data_);
static void tuba_widgets_scheduled_status_on_schedule_picked_real_finish (TubaWidgetsScheduledStatus* self,
                                                                   GAsyncResult* _res_);
static void tuba_widgets_scheduled_status_on_schedule_picked_real_data_free (gpointer _data);
static gboolean tuba_widgets_scheduled_status_on_schedule_picked_real_co (TubaWidgetsScheduledStatusOnSchedulePickedRealData* _data_);
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN const gchar* tuba_api_scheduled_status_get_id (TubaAPIScheduledStatus* self);
VALA_EXTERN GType tuba_request_v2_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaRequestV2* tuba_request_v2_new (const gchar* url,
                                    TubaRequestV2Method method);
VALA_EXTERN TubaRequestV2* tuba_request_v2_construct (GType object_type,
                                          const gchar* url,
                                          TubaRequestV2Method method);
VALA_EXTERN void tuba_request_v2_set_account (TubaRequestV2* self,
                                  TubaInstanceAccount* value);
VALA_EXTERN void tuba_request_v2_add_form_data (TubaRequestV2* self,
                                    const gchar* name,
                                    const gchar* val);
VALA_EXTERN void tuba_request_v2_exec (TubaRequestV2* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN GQuark tuba_oopsie_quark (void);
VALA_EXTERN GType tuba_oopsie_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GInputStream* tuba_request_v2_exec_finish (TubaRequestV2* self,
                                           GAsyncResult* _res_,
                                           SoupMessageHeaders** response_headers,
                                           GError** error);
static void tuba_widgets_scheduled_status_on_schedule_picked_real_ready (GObject* source_object,
                                                                  GAsyncResult* _res_,
                                                                  gpointer _user_data_);
VALA_EXTERN void tuba_network_get_parser_from_inputstream_async (GInputStream* in_stream,
                                                     GCancellable* cancellable,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN JsonParser* tuba_network_get_parser_from_inputstream_finish (GAsyncResult* _res_,
                                                             GError** error);
VALA_EXTERN GType tuba_network_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaNetwork, g_object_unref)
VALA_EXTERN JsonNode* tuba_network_parse_node (TubaNetwork* self,
                                   JsonParser* parser);
VALA_EXTERN TubaEntity* tuba_helper_entity_from_json (JsonNode* node,
                                          GType type,
                                          gboolean force);
static JsonNode* _vala_JsonNode_copy (JsonNode* self);
static void _vala_JsonNode_free (JsonNode* self);
static void tuba_widgets_scheduled_status_on_delete (TubaWidgetsScheduledStatus* self);
VALA_EXTERN GType tuba_application_question_text_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaApplicationQuestionText* tuba_application_question_text_dup (const TubaApplicationQuestionText* self);
VALA_EXTERN void tuba_application_question_text_free (TubaApplicationQuestionText* self);
VALA_EXTERN void tuba_application_question_text_copy (const TubaApplicationQuestionText* self,
                                          TubaApplicationQuestionText* dest);
VALA_EXTERN void tuba_application_question_text_destroy (TubaApplicationQuestionText* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaApplicationQuestionText, tuba_application_question_text_destroy)
VALA_EXTERN GType tuba_application_question_buttons_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_application_question_button_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaApplicationQuestionButton* tuba_application_question_button_dup (const TubaApplicationQuestionButton* self);
VALA_EXTERN void tuba_application_question_button_free (TubaApplicationQuestionButton* self);
VALA_EXTERN void tuba_application_question_button_copy (const TubaApplicationQuestionButton* self,
                                            TubaApplicationQuestionButton* dest);
VALA_EXTERN void tuba_application_question_button_destroy (TubaApplicationQuestionButton* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaApplicationQuestionButton, tuba_application_question_button_destroy)
VALA_EXTERN TubaApplicationQuestionButtons* tuba_application_question_buttons_dup (const TubaApplicationQuestionButtons* self);
VALA_EXTERN void tuba_application_question_buttons_free (TubaApplicationQuestionButtons* self);
VALA_EXTERN void tuba_application_question_buttons_copy (const TubaApplicationQuestionButtons* self,
                                             TubaApplicationQuestionButtons* dest);
VALA_EXTERN void tuba_application_question_buttons_destroy (TubaApplicationQuestionButtons* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaApplicationQuestionButtons, tuba_application_question_buttons_destroy)
VALA_EXTERN void tuba_application_question (TubaApplication* self,
                                TubaApplicationQuestionText* title,
                                TubaApplicationQuestionText* msg,
                                GtkWidget* win,
                                TubaApplicationQuestionButtons* buttons,
                                GtkWidget* child,
                                gboolean skip,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_);
VALA_EXTERN GType tuba_application_question_answer_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaApplicationQuestionAnswer tuba_application_question_finish (TubaApplication* self,
                                                                GAsyncResult* _res_);
static void __lambda81_ (TubaWidgetsScheduledStatus* self,
                  GObject* obj,
                  GAsyncResult* res);
VALA_EXTERN gboolean tuba_application_question_answer_truthy (TubaApplicationQuestionAnswer self);
static void tuba_widgets_scheduled_status_delete_status (TubaWidgetsScheduledStatus* self,
                                                  GAsyncReadyCallback _callback_,
                                                  gpointer _user_data_);
static void tuba_widgets_scheduled_status_delete_status_finish (TubaWidgetsScheduledStatus* self,
                                                         GAsyncResult* _res_);
static void ___lambda81__gasync_ready_callback (GObject* source_object,
                                         GAsyncResult* res,
                                         gpointer self);
static void tuba_widgets_scheduled_status_delete_status_data_free (gpointer _data);
static gboolean tuba_widgets_scheduled_status_delete_status_co (TubaWidgetsScheduledStatusDeleteStatusData* _data_);
static void tuba_widgets_scheduled_status_delete_status_ready (GObject* source_object,
                                                        GAsyncResult* _res_,
                                                        gpointer _user_data_);
VALA_EXTERN gboolean tuba_widgets_scheduled_status_get_is_inline (TubaWidgetsScheduledStatus* self);
static void tuba_widgets_scheduled_status_on_activated (TubaWidgetsScheduledStatus* self);
VALA_EXTERN void tuba_widgets_scheduled_status_compose_draft (TubaWidgetsScheduledStatus* self);
static void tuba_widgets_scheduled_status_on_draft_posted (TubaWidgetsScheduledStatus* self,
                                                    TubaAPIStatus* x);
static void _tuba_widgets_scheduled_status_on_draft_posted_tuba_dialogs_composer_dialog_success_callback (TubaAPIStatus* cb_status,
                                                                                                   gpointer self);
VALA_EXTERN TubaDialogsComposerDialog* tuba_dialogs_composer_dialog_new_from_scheduled (TubaAPIScheduledStatus* scheduled_status,
                                                                            gboolean posting_draft,
                                                                            TubaAPIPoll* poll,
                                                                            TubaDialogsComposerDialogSuccessCallback t_cb,
                                                                            gpointer t_cb_target,
                                                                            GDestroyNotify t_cb_target_destroy_notify);
VALA_EXTERN TubaDialogsComposerDialog* tuba_dialogs_composer_dialog_construct_from_scheduled (GType object_type,
                                                                                  TubaAPIScheduledStatus* scheduled_status,
                                                                                  gboolean posting_draft,
                                                                                  TubaAPIPoll* poll,
                                                                                  TubaDialogsComposerDialogSuccessCallback t_cb,
                                                                                  gpointer t_cb_target,
                                                                                  GDestroyNotify t_cb_target_destroy_notify);
VALA_EXTERN GType tuba_dialogs_composer_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsComposerDialog, g_object_unref)
static void tuba_widgets_scheduled_status_on_edit (TubaWidgetsScheduledStatus* self);
static void tuba_widgets_scheduled_status_on_edited (TubaWidgetsScheduledStatus* self,
                                              TubaAPIStatus* x);
static void _tuba_widgets_scheduled_status_on_edited_tuba_dialogs_composer_dialog_success_callback (TubaAPIStatus* cb_status,
                                                                                             gpointer self);
VALA_EXTERN gboolean tuba_widgets_scheduled_status_get_draft (TubaWidgetsScheduledStatus* self);
VALA_EXTERN void tuba_widgets_scheduled_status_set_draft (TubaWidgetsScheduledStatus* self,
                                              gboolean value);
VALA_EXTERN void tuba_widgets_scheduled_status_set_is_inline (TubaWidgetsScheduledStatus* self,
                                                  gboolean value);
VALA_EXTERN GType tuba_dialogs_schedule_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsSchedule, g_object_unref)
VALA_EXTERN TubaDialogsSchedule* tuba_dialogs_schedule_new (const gchar* iso8601,
                                                const gchar* button_label);
VALA_EXTERN TubaDialogsSchedule* tuba_dialogs_schedule_construct (GType object_type,
                                                      const gchar* iso8601,
                                                      const gchar* button_label);
VALA_EXTERN void tuba_dialogs_schedule_set_can_cancel (TubaDialogsSchedule* self,
                                           gboolean value);
static void tuba_widgets_scheduled_status_reschedule_dialog_on_schedule_picked (TubaWidgetsScheduledStatusRescheduleDialog* self,
                                                                         const gchar* iso8601);
static void _tuba_widgets_scheduled_status_reschedule_dialog_on_schedule_picked_tuba_dialogs_schedule_schedule_picked (TubaDialogsSchedule* _sender,
                                                                                                                const gchar* iso8601,
                                                                                                                gpointer self);
static void tuba_widgets_scheduled_status_reschedule_dialog_on_cancel (TubaWidgetsScheduledStatusRescheduleDialog* self);
static void _tuba_widgets_scheduled_status_reschedule_dialog_on_cancel_tuba_dialogs_schedule_cancelled (TubaDialogsSchedule* _sender,
                                                                                                 gpointer self);
static GType tuba_widgets_scheduled_status_reschedule_dialog_get_type_once (void);
static GObject * tuba_widgets_scheduled_status_constructor (GType type,
                                                     guint n_construct_properties,
                                                     GObjectConstructParam * construct_properties);
static void _tuba_widgets_scheduled_status_on_edit_gtk_button_clicked (GtkButton* _sender,
                                                                gpointer self);
static void _tuba_widgets_scheduled_status_on_reschedule_gtk_button_clicked (GtkButton* _sender,
                                                                      gpointer self);
static void _tuba_widgets_scheduled_status_on_convert_to_draft_gtk_button_clicked (GtkButton* _sender,
                                                                            gpointer self);
static void _tuba_widgets_scheduled_status_on_delete_gtk_button_clicked (GtkButton* _sender,
                                                                  gpointer self);
static void _tuba_widgets_scheduled_status_on_activated_tuba_widgets_scheduled_status_open (TubaWidgetsScheduledStatus* _sender,
                                                                                     gpointer self);
static void tuba_widgets_scheduled_status_finalize (GObject * obj);
static GType tuba_widgets_scheduled_status_get_type_once (void);
static void _vala_tuba_widgets_scheduled_status_get_property (GObject * object,
                                                       guint property_id,
                                                       GValue * value,
                                                       GParamSpec * pspec);
static void _vala_tuba_widgets_scheduled_status_set_property (GObject * object,
                                                       guint property_id,
                                                       const GValue * value,
                                                       GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
tuba_widgets_scheduled_status_get_instance_private (TubaWidgetsScheduledStatus* self)
{
	return G_STRUCT_MEMBER_P (self, TubaWidgetsScheduledStatus_private_offset);
}

TubaWidgetsScheduledStatus*
tuba_widgets_scheduled_status_construct (GType object_type,
                                         TubaAPIScheduledStatus* scheduled_status)
{
	TubaWidgetsScheduledStatus * self = NULL;
	g_return_val_if_fail (scheduled_status != NULL, NULL);
	self = (TubaWidgetsScheduledStatus*) g_object_new (object_type, NULL);
	tuba_widgets_scheduled_status_bind (self, scheduled_status);
	return self;
}

TubaWidgetsScheduledStatus*
tuba_widgets_scheduled_status_new (TubaAPIScheduledStatus* scheduled_status)
{
	return tuba_widgets_scheduled_status_construct (TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, scheduled_status);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static gchar*
string_replace (const gchar* self,
                const gchar* old,
                const gchar* replacement)
{
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError* _inner_error0_ = NULL;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (old != NULL, NULL);
	g_return_val_if_fail (replacement != NULL, NULL);
	if ((*((gchar*) self)) == '\0') {
		_tmp1_ = TRUE;
	} else {
		_tmp1_ = (*((gchar*) old)) == '\0';
	}
	if (_tmp1_) {
		_tmp0_ = TRUE;
	} else {
		_tmp0_ = g_strcmp0 (old, replacement) == 0;
	}
	if (_tmp0_) {
		gchar* _tmp2_;
		_tmp2_ = g_strdup (self);
		result = _tmp2_;
		return result;
	}
	{
		GRegex* regex = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
		GRegex* _tmp5_;
		GRegex* _tmp6_;
		gchar* _tmp7_ = NULL;
		GRegex* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		_tmp3_ = g_regex_escape_string (old, -1);
		_tmp4_ = _tmp3_;
		_tmp5_ = g_regex_new (_tmp4_, 0, 0, &_inner_error0_);
		_tmp6_ = _tmp5_;
		_g_free0 (_tmp4_);
		regex = _tmp6_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch0_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp8_ = regex;
		_tmp9_ = g_regex_replace_literal (_tmp8_, self, (gssize) -1, 0, replacement, 0, &_inner_error0_);
		_tmp7_ = _tmp9_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			_g_regex_unref0 (regex);
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch0_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp10_ = _tmp7_;
		_tmp7_ = NULL;
		result = _tmp10_;
		_g_free0 (_tmp7_);
		_g_regex_unref0 (regex);
		return result;
	}
	goto __finally0;
	__catch0_g_regex_error:
	{
		g_clear_error (&_inner_error0_);
		g_assert_not_reached ();
	}
	__finally0:
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
	g_clear_error (&_inner_error0_);
	return NULL;
}

void
tuba_widgets_scheduled_status_bind (TubaWidgetsScheduledStatus* self,
                                    TubaAPIScheduledStatus* scheduled_status)
{
	TubaWidgetsStatus* _tmp0_;
	TubaAPIScheduledStatus* _tmp3_;
	GDateTime* now_load = NULL;
	GDateTime* _tmp4_;
	TubaAPIScheduledStatusParams* _tmp5_;
	TubaAPIScheduledStatusParams* _tmp6_;
	TubaAPIScheduledStatusParamsPoll* _tmp7_;
	TubaAPIScheduledStatusParamsPoll* _tmp8_;
	TubaAPIStatus* status = NULL;
	TubaAccountStore* _tmp49_;
	TubaInstanceAccount* _tmp50_;
	TubaInstanceAccount* _tmp51_;
	TubaAPIAccount* _tmp52_;
	TubaAPIScheduledStatusParams* _tmp53_;
	TubaAPIScheduledStatusParams* _tmp54_;
	const gchar* _tmp55_;
	const gchar* _tmp56_;
	gchar* _tmp57_;
	TubaAPIScheduledStatusParams* _tmp58_;
	TubaAPIScheduledStatusParams* _tmp59_;
	const gchar* _tmp60_;
	const gchar* _tmp61_;
	gchar* _tmp62_;
	TubaAPIScheduledStatusParams* _tmp63_;
	TubaAPIScheduledStatusParams* _tmp64_;
	gboolean _tmp65_;
	gboolean _tmp66_;
	TubaAPIScheduledStatusParams* _tmp67_;
	TubaAPIScheduledStatusParams* _tmp68_;
	const gchar* _tmp69_;
	const gchar* _tmp70_;
	gchar* _tmp71_;
	GeeArrayList* _tmp72_;
	GeeArrayList* _tmp73_;
	GeeArrayList* _tmp74_;
	TubaAPIPoll* _tmp75_;
	TubaAPIPoll* _tmp76_;
	const gchar* _tmp77_;
	const gchar* _tmp78_;
	gchar* _tmp79_;
	TubaAPIStatus* _tmp80_ = NULL;
	TubaAPIScheduledStatusParams* _tmp81_;
	TubaAPIScheduledStatusParams* _tmp82_;
	const gchar* _tmp83_;
	const gchar* _tmp84_;
	TubaWidgetsStatus* widg = NULL;
	TubaAPIStatus* _tmp90_;
	TubaWidgetsStatus* _tmp91_;
	TubaWidgetsStatus* _tmp92_;
	TubaWidgetsStatus* _tmp93_;
	TubaWidgetsStatus* _tmp94_;
	TubaWidgetsStatus* _tmp95_;
	GtkMenuButton* _tmp96_;
	TubaWidgetsStatus* _tmp97_;
	GtkLabel* _tmp98_;
	TubaWidgetsStatus* _tmp99_;
	TubaWidgetsVoteBox* _tmp100_;
	GDateTime* date_parsed = NULL;
	const gchar* _tmp111_;
	const gchar* _tmp112_;
	GDateTime* _tmp113_;
	GTimeSpan delta = 0LL;
	GDateTime* _tmp114_;
	GDateTime* _tmp115_;
	GDateTime* _tmp116_;
	GDateTime* _tmp117_;
	GTimeSpan _tmp118_;
	GtkButton* _tmp119_;
	GDateTime* _tmp120_;
	GTimeZone* _tmp121_;
	GTimeZone* _tmp122_;
	GDateTime* _tmp123_;
	gchar* date_local = NULL;
	gchar* _tmp124_;
	GtkLabel* _tmp125_;
	GDateTime* _tmp126_;
	const gchar* _tmp127_;
	gchar* _tmp128_;
	gchar* _tmp129_;
	gchar* _tmp130_;
	gchar* _tmp131_;
	gchar* _tmp132_;
	gchar* _tmp133_;
	gchar* _tmp134_;
	gchar* _tmp135_;
	GtkBox* _tmp136_;
	TubaWidgetsStatus* _tmp137_;
	TubaWidgetsStatus* _tmp138_;
	TubaWidgetsStatus* _tmp139_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (scheduled_status != NULL);
	_tmp0_ = self->priv->status_widget;
	if (_tmp0_ != NULL) {
		GtkBox* _tmp1_;
		TubaWidgetsStatus* _tmp2_;
		_tmp1_ = self->priv->content_box;
		_tmp2_ = self->priv->status_widget;
		gtk_box_remove (_tmp1_, (GtkWidget*) _tmp2_);
	}
	_tmp3_ = _g_object_ref0 (scheduled_status);
	_g_object_unref0 (self->priv->bound_scheduled_status);
	self->priv->bound_scheduled_status = _tmp3_;
	_tmp4_ = g_date_time_new_now_local ();
	now_load = _tmp4_;
	_g_object_unref0 (self->priv->status_poll);
	self->priv->status_poll = NULL;
	_tmp5_ = tuba_api_scheduled_status_get_props (scheduled_status);
	_tmp6_ = _tmp5_;
	_tmp7_ = tuba_api_scheduled_status_params_get_poll (_tmp6_);
	_tmp8_ = _tmp7_;
	if (_tmp8_ != NULL) {
		TubaAPIScheduledStatusParams* _tmp9_;
		TubaAPIScheduledStatusParams* _tmp10_;
		TubaAPIScheduledStatusParamsPoll* _tmp11_;
		TubaAPIScheduledStatusParamsPoll* _tmp12_;
		gboolean _tmp13_;
		gboolean _tmp14_;
		GeeArrayList* _tmp15_;
		TubaAPIPoll* _tmp16_ = NULL;
		TubaAPIPoll* _tmp37_;
		GDateTime* _tmp38_;
		TubaAPIScheduledStatusParams* _tmp39_;
		TubaAPIScheduledStatusParams* _tmp40_;
		TubaAPIScheduledStatusParamsPoll* _tmp41_;
		TubaAPIScheduledStatusParamsPoll* _tmp42_;
		gint64 _tmp43_;
		gint64 _tmp44_;
		GDateTime* _tmp45_;
		GDateTime* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		_tmp9_ = tuba_api_scheduled_status_get_props (scheduled_status);
		_tmp10_ = _tmp9_;
		_tmp11_ = tuba_api_scheduled_status_params_get_poll (_tmp10_);
		_tmp12_ = _tmp11_;
		_tmp13_ = tuba_api_scheduled_status_params_poll_get_multiple (_tmp12_);
		_tmp14_ = _tmp13_;
		_tmp15_ = gee_array_list_new (TUBA_API_TYPE_POLL_OPTION, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
		_tmp16_ = tuba_api_poll_new ("0");
		tuba_api_poll_set_multiple (_tmp16_, _tmp14_);
		tuba_api_poll_set_options (_tmp16_, _tmp15_);
		_g_object_unref0 (_tmp15_);
		_g_object_unref0 (self->priv->status_poll);
		self->priv->status_poll = _tmp16_;
		{
			GeeArrayList* _poll_option_list = NULL;
			TubaAPIScheduledStatusParams* _tmp17_;
			TubaAPIScheduledStatusParams* _tmp18_;
			TubaAPIScheduledStatusParamsPoll* _tmp19_;
			TubaAPIScheduledStatusParamsPoll* _tmp20_;
			GeeArrayList* _tmp21_;
			GeeArrayList* _tmp22_;
			gint _poll_option_size = 0;
			GeeArrayList* _tmp23_;
			gint _tmp24_;
			gint _tmp25_;
			gint _poll_option_index = 0;
			_tmp17_ = tuba_api_scheduled_status_get_props (scheduled_status);
			_tmp18_ = _tmp17_;
			_tmp19_ = tuba_api_scheduled_status_params_get_poll (_tmp18_);
			_tmp20_ = _tmp19_;
			_tmp21_ = tuba_api_scheduled_status_params_poll_get_options (_tmp20_);
			_tmp22_ = _tmp21_;
			_poll_option_list = _tmp22_;
			_tmp23_ = _poll_option_list;
			_tmp24_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp23_);
			_tmp25_ = _tmp24_;
			_poll_option_size = _tmp25_;
			_poll_option_index = -1;
			while (TRUE) {
				gint _tmp26_;
				gint _tmp27_;
				gchar* poll_option = NULL;
				GeeArrayList* _tmp28_;
				gpointer _tmp29_;
				TubaAPIPoll* _tmp30_;
				GeeArrayList* _tmp31_;
				GeeArrayList* _tmp32_;
				const gchar* _tmp33_;
				gchar* _tmp34_;
				TubaAPIPollOption* _tmp35_ = NULL;
				TubaAPIPollOption* _tmp36_;
				_poll_option_index = _poll_option_index + 1;
				_tmp26_ = _poll_option_index;
				_tmp27_ = _poll_option_size;
				if (!(_tmp26_ < _tmp27_)) {
					break;
				}
				_tmp28_ = _poll_option_list;
				_tmp29_ = gee_abstract_list_get ((GeeAbstractList*) _tmp28_, _poll_option_index);
				poll_option = (gchar*) _tmp29_;
				_tmp30_ = self->priv->status_poll;
				_tmp31_ = tuba_api_poll_get_options (_tmp30_);
				_tmp32_ = _tmp31_;
				_tmp33_ = poll_option;
				_tmp34_ = g_strdup (_tmp33_);
				_tmp35_ = tuba_api_poll_option_new ();
				tuba_api_poll_option_set_title (_tmp35_, _tmp34_);
				_g_free0 (_tmp34_);
				tuba_api_poll_option_set_votes_count (_tmp35_, (gint64) 0);
				_tmp36_ = _tmp35_;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp32_, _tmp36_);
				_g_object_unref0 (_tmp36_);
				_g_free0 (poll_option);
			}
		}
		_tmp37_ = self->priv->status_poll;
		_tmp38_ = now_load;
		_tmp39_ = tuba_api_scheduled_status_get_props (scheduled_status);
		_tmp40_ = _tmp39_;
		_tmp41_ = tuba_api_scheduled_status_params_get_poll (_tmp40_);
		_tmp42_ = _tmp41_;
		_tmp43_ = tuba_api_scheduled_status_params_poll_get_expires_in (_tmp42_);
		_tmp44_ = _tmp43_;
		_tmp45_ = g_date_time_add_seconds (_tmp38_, (gdouble) _tmp44_);
		_tmp46_ = _tmp45_;
		_tmp47_ = g_date_time_format_iso8601 (_tmp46_);
		_tmp48_ = _tmp47_;
		tuba_api_poll_set_expires_at (_tmp37_, _tmp48_);
		_g_free0 (_tmp48_);
		_g_date_time_unref0 (_tmp46_);
	}
	_tmp49_ = tuba_accounts;
	_tmp50_ = tuba_account_store_get_active (_tmp49_);
	_tmp51_ = _tmp50_;
	_tmp52_ = _g_object_ref0 ((TubaAPIAccount*) _tmp51_);
	_tmp53_ = tuba_api_scheduled_status_get_props (scheduled_status);
	_tmp54_ = _tmp53_;
	_tmp55_ = tuba_api_scheduled_status_params_get_spoiler_text (_tmp54_);
	_tmp56_ = _tmp55_;
	_tmp57_ = g_strdup (_tmp56_);
	_tmp58_ = tuba_api_scheduled_status_get_props (scheduled_status);
	_tmp59_ = _tmp58_;
	_tmp60_ = tuba_api_scheduled_status_params_get_text (_tmp59_);
	_tmp61_ = _tmp60_;
	_tmp62_ = g_strdup (_tmp61_);
	_tmp63_ = tuba_api_scheduled_status_get_props (scheduled_status);
	_tmp64_ = _tmp63_;
	_tmp65_ = tuba_api_scheduled_status_params_get_sensitive (_tmp64_);
	_tmp66_ = _tmp65_;
	_tmp67_ = tuba_api_scheduled_status_get_props (scheduled_status);
	_tmp68_ = _tmp67_;
	_tmp69_ = tuba_api_scheduled_status_params_get_visibility (_tmp68_);
	_tmp70_ = _tmp69_;
	_tmp71_ = g_strdup (_tmp70_);
	_tmp72_ = tuba_api_scheduled_status_get_media_attachments (scheduled_status);
	_tmp73_ = _tmp72_;
	_tmp74_ = _g_object_ref0 (_tmp73_);
	_tmp75_ = self->priv->status_poll;
	_tmp76_ = _g_object_ref0 (_tmp75_);
	_tmp77_ = tuba_api_scheduled_status_get_scheduled_at (scheduled_status);
	_tmp78_ = _tmp77_;
	_tmp79_ = g_strdup (_tmp78_);
	_tmp80_ = tuba_api_status_new_empty ();
	tuba_api_status_set_account (_tmp80_, _tmp52_);
	_g_object_unref0 (_tmp52_);
	tuba_api_status_set_spoiler_text (_tmp80_, _tmp57_);
	_g_free0 (_tmp57_);
	tuba_api_status_set_content (_tmp80_, _tmp62_);
	_g_free0 (_tmp62_);
	tuba_api_status_set_sensitive (_tmp80_, _tmp66_);
	tuba_api_status_set_visibility (_tmp80_, _tmp71_);
	_g_free0 (_tmp71_);
	tuba_api_status_set_media_attachments (_tmp80_, _tmp74_);
	_g_object_unref0 (_tmp74_);
	tuba_api_status_set_tuba_spoiler_revealed (_tmp80_, TRUE);
	tuba_api_status_set_poll (_tmp80_, _tmp76_);
	_g_object_unref0 (_tmp76_);
	tuba_api_status_set_created_at (_tmp80_, _tmp79_);
	_g_free0 (_tmp79_);
	status = _tmp80_;
	_tmp81_ = tuba_api_scheduled_status_get_props (scheduled_status);
	_tmp82_ = _tmp81_;
	_tmp83_ = tuba_api_scheduled_status_params_get_language (_tmp82_);
	_tmp84_ = _tmp83_;
	if (_tmp84_ != NULL) {
		TubaAPIStatus* _tmp85_;
		TubaAPIScheduledStatusParams* _tmp86_;
		TubaAPIScheduledStatusParams* _tmp87_;
		const gchar* _tmp88_;
		const gchar* _tmp89_;
		_tmp85_ = status;
		_tmp86_ = tuba_api_scheduled_status_get_props (scheduled_status);
		_tmp87_ = _tmp86_;
		_tmp88_ = tuba_api_scheduled_status_params_get_language (_tmp87_);
		_tmp89_ = _tmp88_;
		tuba_api_status_set_language (_tmp85_, _tmp89_);
	}
	_tmp90_ = status;
	_tmp91_ = tuba_widgets_status_new (_tmp90_);
	g_object_ref_sink (_tmp91_);
	widg = _tmp91_;
	_tmp92_ = widg;
	tuba_widgets_status_set_can_be_opened (_tmp92_, FALSE);
	_tmp93_ = widg;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp93_, FALSE);
	_tmp94_ = widg;
	tuba_widgets_status_toggle_actions_visibility (_tmp94_, FALSE);
	_tmp95_ = widg;
	_tmp96_ = _tmp95_->menu_button;
	gtk_widget_set_visible ((GtkWidget*) _tmp96_, FALSE);
	_tmp97_ = widg;
	_tmp98_ = _tmp97_->date_label;
	gtk_widget_set_visible ((GtkWidget*) _tmp98_, FALSE);
	_tmp99_ = widg;
	_tmp100_ = _tmp99_->poll;
	if (_tmp100_ != NULL) {
		TubaWidgetsStatus* _tmp101_;
		TubaWidgetsVoteBox* _tmp102_;
		TubaWidgetsStatus* _tmp103_;
		TubaWidgetsVoteBox* _tmp104_;
		GtkLabel* _tmp105_;
		TubaAPIPoll* _tmp106_;
		const gchar* _tmp107_;
		const gchar* _tmp108_;
		gchar* _tmp109_;
		gchar* _tmp110_;
		_tmp101_ = widg;
		_tmp102_ = _tmp101_->poll;
		tuba_widgets_vote_box_set_usable (_tmp102_, FALSE);
		_tmp103_ = widg;
		_tmp104_ = _tmp103_->poll;
		_tmp105_ = _tmp104_->info_label;
		_tmp106_ = self->priv->status_poll;
		_tmp107_ = tuba_api_poll_get_expires_at (_tmp106_);
		_tmp108_ = _tmp107_;
		_tmp109_ = tuba_utils_date_time_humanize_ago (_tmp108_);
		_tmp110_ = _tmp109_;
		gtk_label_set_label (_tmp105_, _tmp110_);
		_g_free0 (_tmp110_);
	}
	_tmp111_ = tuba_api_scheduled_status_get_scheduled_at (scheduled_status);
	_tmp112_ = _tmp111_;
	_tmp113_ = g_date_time_new_from_iso8601 (_tmp112_, NULL);
	date_parsed = _tmp113_;
	_tmp114_ = date_parsed;
	_tmp115_ = g_date_time_to_local (_tmp114_);
	_tmp116_ = _tmp115_;
	_tmp117_ = now_load;
	_tmp118_ = g_date_time_difference (_tmp116_, _tmp117_);
	_g_date_time_unref0 (_tmp116_);
	delta = _tmp118_;
	_tmp119_ = self->priv->edit_button;
	gtk_widget_set_visible ((GtkWidget*) _tmp119_, delta >= G_TIME_SPAN_HOUR);
	_tmp120_ = date_parsed;
	_tmp121_ = g_time_zone_new_local ();
	_tmp122_ = _tmp121_;
	_tmp123_ = g_date_time_to_timezone (_tmp120_, _tmp122_);
	_g_date_time_unref0 (date_parsed);
	date_parsed = _tmp123_;
	_g_time_zone_unref0 (_tmp122_);
	_tmp124_ = g_strdup (_ ("%B %e, %Y"));
	date_local = _tmp124_;
	_tmp125_ = self->priv->schedule_label;
	_tmp126_ = date_parsed;
	_tmp127_ = string_to_string (date_local);
	_tmp128_ = g_strconcat (_tmp127_, " · %H:%M", NULL);
	_tmp129_ = _tmp128_;
	_tmp130_ = g_date_time_format (_tmp126_, _tmp129_);
	_tmp131_ = _tmp130_;
	_tmp132_ = string_replace (_tmp131_, " ", "");
	_tmp133_ = _tmp132_;
	_tmp134_ = g_strdup_printf (_ ("Scheduled for %s"), _tmp133_);
	_tmp135_ = _tmp134_;
	gtk_label_set_label (_tmp125_, _tmp135_);
	_g_free0 (_tmp135_);
	_g_free0 (_tmp133_);
	_g_free0 (_tmp131_);
	_g_free0 (_tmp129_);
	_tmp136_ = self->priv->content_box;
	_tmp137_ = widg;
	gtk_box_append (_tmp136_, (GtkWidget*) _tmp137_);
	_tmp138_ = widg;
	_tmp139_ = _g_object_ref0 (_tmp138_);
	_g_object_unref0 (self->priv->status_widget);
	self->priv->status_widget = _tmp139_;
	_g_free0 (date_local);
	_g_date_time_unref0 (date_parsed);
	_g_object_unref0 (widg);
	_g_object_unref0 (status);
	_g_date_time_unref0 (now_load);
}

static void
tuba_widgets_scheduled_status_on_convert_to_draft (TubaWidgetsScheduledStatus* self)
{
	GTimeZone* _tmp0_;
	GTimeZone* _tmp1_;
	GDateTime* _tmp2_;
	GDateTime* _tmp3_;
	GDateTime* _tmp4_;
	GDateTime* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_time_zone_new_local ();
	_tmp1_ = _tmp0_;
	_tmp2_ = g_date_time_new_now (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_date_time_add_years (_tmp3_, 3000);
	_tmp5_ = _tmp4_;
	_tmp6_ = g_date_time_format_iso8601 (_tmp5_);
	_tmp7_ = _tmp6_;
	tuba_widgets_scheduled_status_on_schedule_picked (self, _tmp7_);
	_g_free0 (_tmp7_);
	_g_date_time_unref0 (_tmp5_);
	_g_date_time_unref0 (_tmp3_);
	_g_time_zone_unref0 (_tmp1_);
}

static void
_tuba_widgets_scheduled_status_on_schedule_picked_tuba_widgets_scheduled_status_reschedule_dialog_schedule_picked (TubaWidgetsScheduledStatusRescheduleDialog* _sender,
                                                                                                                   const gchar* iso8601,
                                                                                                                   gpointer self)
{
	tuba_widgets_scheduled_status_on_schedule_picked ((TubaWidgetsScheduledStatus*) self, iso8601);
}

static void
tuba_widgets_scheduled_status_on_reschedule (TubaWidgetsScheduledStatus* self)
{
	TubaWidgetsScheduledStatusRescheduleDialog* dlg = NULL;
	TubaAPIScheduledStatus* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	TubaWidgetsScheduledStatusRescheduleDialog* _tmp3_;
	TubaApplication* _tmp4_;
	TubaDialogsMainWindow* _tmp5_;
	TubaDialogsMainWindow* _tmp6_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->bound_scheduled_status;
	_tmp1_ = tuba_api_scheduled_status_get_scheduled_at (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = tuba_widgets_scheduled_status_reschedule_dialog_new (_tmp2_);
	g_object_ref_sink (_tmp3_);
	dlg = _tmp3_;
	g_signal_connect_object (dlg, "schedule-picked", (GCallback) _tuba_widgets_scheduled_status_on_schedule_picked_tuba_widgets_scheduled_status_reschedule_dialog_schedule_picked, self, 0);
	_tmp4_ = tuba_app;
	_tmp5_ = tuba_application_get_main_window (_tmp4_);
	_tmp6_ = _tmp5_;
	adw_dialog_present ((AdwDialog*) dlg, (GtkWidget*) _tmp6_);
	_g_object_unref0 (dlg);
}

static void
tuba_widgets_scheduled_status_on_schedule_picked (TubaWidgetsScheduledStatus* self,
                                                  const gchar* iso8601)
{
	g_return_if_fail (self != NULL);
	g_return_if_fail (iso8601 != NULL);
	tuba_widgets_scheduled_status_on_schedule_picked_real (self, iso8601, NULL, NULL);
}

static void
tuba_widgets_scheduled_status_on_schedule_picked_real_data_free (gpointer _data)
{
	TubaWidgetsScheduledStatusOnSchedulePickedRealData* _data_;
	_data_ = _data;
	_g_free0 (_data_->iso8601);
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaWidgetsScheduledStatusOnSchedulePickedRealData, _data_);
}

static void
tuba_widgets_scheduled_status_on_schedule_picked_real (TubaWidgetsScheduledStatus* self,
                                                       const gchar* iso8601,
                                                       GAsyncReadyCallback _callback_,
                                                       gpointer _user_data_)
{
	TubaWidgetsScheduledStatusOnSchedulePickedRealData* _data_;
	TubaWidgetsScheduledStatus* _tmp0_;
	gchar* _tmp1_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (iso8601 != NULL);
	_data_ = g_slice_new0 (TubaWidgetsScheduledStatusOnSchedulePickedRealData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_widgets_scheduled_status_on_schedule_picked_real_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = g_strdup (iso8601);
	_g_free0 (_data_->iso8601);
	_data_->iso8601 = _tmp1_;
	tuba_widgets_scheduled_status_on_schedule_picked_real_co (_data_);
}

static void
tuba_widgets_scheduled_status_on_schedule_picked_real_finish (TubaWidgetsScheduledStatus* self,
                                                              GAsyncResult* _res_)
{
	TubaWidgetsScheduledStatusOnSchedulePickedRealData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
tuba_widgets_scheduled_status_on_schedule_picked_real_ready (GObject* source_object,
                                                             GAsyncResult* _res_,
                                                             gpointer _user_data_)
{
	TubaWidgetsScheduledStatusOnSchedulePickedRealData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_widgets_scheduled_status_on_schedule_picked_real_co (_data_);
}

static JsonNode*
_vala_JsonNode_copy (JsonNode* self)
{
	return g_boxed_copy (json_node_get_type (), self);
}

static gpointer
__vala_JsonNode_copy0 (gpointer self)
{
	return self ? _vala_JsonNode_copy (self) : NULL;
}

static void
_vala_JsonNode_free (JsonNode* self)
{
	g_boxed_free (json_node_get_type (), self);
}

static gboolean
tuba_widgets_scheduled_status_on_schedule_picked_real_co (TubaWidgetsScheduledStatusOnSchedulePickedRealData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = _data_->self->priv->bound_scheduled_status;
	_data_->_tmp1_ = tuba_api_scheduled_status_get_id (_data_->_tmp0_);
	_data_->_tmp2_ = _data_->_tmp1_;
	_data_->_tmp3_ = string_to_string (_data_->_tmp2_);
	_data_->_tmp4_ = g_strconcat ("/api/v1/scheduled_statuses/", _data_->_tmp3_, NULL);
	_data_->_tmp5_ = _data_->_tmp4_;
	_data_->_tmp6_ = tuba_accounts;
	_data_->_tmp7_ = tuba_account_store_get_active (_data_->_tmp6_);
	_data_->_tmp8_ = _data_->_tmp7_;
	_data_->_tmp9_ = _g_object_ref0 (_data_->_tmp8_);
	_data_->_tmp10_ = NULL;
	_data_->_tmp10_ = tuba_request_v2_new (_data_->_tmp5_, TUBA_REQUEST_V2_METHOD_PUT);
	tuba_request_v2_set_account (_data_->_tmp10_, _data_->_tmp9_);
	_g_object_unref0 (_data_->_tmp9_);
	_data_->_tmp11_ = _data_->_tmp10_;
	_g_free0 (_data_->_tmp5_);
	_data_->req = _data_->_tmp11_;
	_data_->_tmp12_ = _data_->req;
	tuba_request_v2_add_form_data (_data_->_tmp12_, "scheduled_at", _data_->iso8601);
	{
		_data_->_tmp13_ = _data_->req;
		_data_->_state_ = 1;
		tuba_request_v2_exec (_data_->_tmp13_, tuba_widgets_scheduled_status_on_schedule_picked_real_ready, _data_);
		return FALSE;
		_state_1:
		_data_->_tmp14_ = tuba_request_v2_exec_finish (_data_->_tmp13_, _data_->_res_, NULL, &_data_->_inner_error0_);
		_data_->in_stream = _data_->_tmp14_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_data_->_tmp15_ = _data_->in_stream;
		_data_->_state_ = 2;
		tuba_network_get_parser_from_inputstream_async (_data_->_tmp15_, NULL, tuba_widgets_scheduled_status_on_schedule_picked_real_ready, _data_);
		return FALSE;
		_state_2:
		_data_->_tmp16_ = tuba_network_get_parser_from_inputstream_finish (_data_->_res_, &_data_->_inner_error0_);
		_data_->parser = _data_->_tmp16_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->in_stream);
			goto __catch0_g_error;
		}
		_data_->_tmp17_ = tuba_network;
		_data_->_tmp18_ = _data_->parser;
		_data_->_tmp19_ = tuba_network_parse_node (_data_->_tmp17_, _data_->_tmp18_);
		_data_->node = _data_->_tmp19_;
		_data_->_tmp20_ = _data_->node;
		_data_->_tmp21_ = __vala_JsonNode_copy0 (_data_->_tmp20_);
		_data_->_tmp22_ = tuba_helper_entity_from_json (_data_->_tmp21_, TUBA_API_TYPE_SCHEDULED_STATUS, TRUE);
		_data_->e = _data_->_tmp22_;
		_data_->_tmp23_ = _data_->e;
		if (TUBA_API_IS_SCHEDULED_STATUS (_data_->_tmp23_)) {
			_data_->_tmp24_ = _data_->e;
			_data_->_tmp25_ = tuba_api_scheduled_status_get_scheduled_at (G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp24_, TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatus));
			_data_->_tmp26_ = _data_->_tmp25_;
			_data_->_tmp27_ = g_date_time_new_from_iso8601 (_data_->_tmp26_, NULL);
			_data_->_tmp28_ = _data_->_tmp27_;
			_data_->_tmp29_ = g_date_time_get_year (_data_->_tmp28_) >= TUBA_API_SCHEDULED_STATUS_DRAFT_YEAR;
			_g_date_time_unref0 (_data_->_tmp28_);
			if (_data_->_tmp29_) {
				_data_->_tmp30_ = _data_->self->priv->bound_scheduled_status;
				_data_->_tmp31_ = tuba_api_scheduled_status_get_id (_data_->_tmp30_);
				_data_->_tmp32_ = _data_->_tmp31_;
				g_signal_emit (_data_->self, tuba_widgets_scheduled_status_signals[TUBA_WIDGETS_SCHEDULED_STATUS_DELETED_SIGNAL], 0, _data_->_tmp32_);
			} else {
				_data_->_tmp33_ = _data_->e;
				tuba_widgets_scheduled_status_bind (_data_->self, G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp33_, TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatus));
			}
		}
		_g_object_unref0 (_data_->e);
		__vala_JsonNode_free0 (_data_->node);
		_g_object_unref0 (_data_->parser);
		_g_object_unref0 (_data_->in_stream);
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->_vala1_e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp34_ = _data_->_vala1_e;
		_data_->_tmp35_ = g_strdup_printf ("%i", _data_->_tmp34_->code);
		_data_->_tmp36_ = _data_->_tmp35_;
		_data_->_tmp37_ = _data_->_vala1_e;
		_data_->_tmp38_ = _data_->_tmp37_->message;
		_data_->_tmp39_ = string_to_string (_data_->_tmp38_);
		_data_->_tmp40_ = g_strconcat ("Error while rescheduling: ", _data_->_tmp36_, " ", _data_->_tmp39_, NULL);
		_data_->_tmp41_ = _data_->_tmp40_;
		g_warning ("ScheduledStatus.vala:235: %s", _data_->_tmp41_);
		_g_free0 (_data_->_tmp41_);
		_g_free0 (_data_->_tmp36_);
		_data_->_tmp42_ = tuba_app;
		_data_->_tmp43_ = _data_->_vala1_e;
		_data_->_tmp44_ = _data_->_tmp43_->message;
		_data_->_tmp45_ = g_strdup_printf (_ ("Couldn't reschedule: %s"), _data_->_tmp44_);
		_data_->_tmp46_ = _data_->_tmp45_;
		g_signal_emit_by_name (_data_->_tmp42_, "toast", _data_->_tmp46_, (guint) 0, NULL, NULL, NULL);
		_g_free0 (_data_->_tmp46_);
		_g_error_free0 (_data_->_vala1_e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_g_object_unref0 (_data_->req);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_g_object_unref0 (_data_->req);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
__lambda81_ (TubaWidgetsScheduledStatus* self,
             GObject* obj,
             GAsyncResult* res)
{
	TubaApplication* _tmp0_;
	g_return_if_fail (res != NULL);
	_tmp0_ = tuba_app;
	if (tuba_application_question_answer_truthy (tuba_application_question_finish (_tmp0_, res))) {
		tuba_widgets_scheduled_status_delete_status (self, NULL, NULL);
	}
}

static void
___lambda81__gasync_ready_callback (GObject* source_object,
                                    GAsyncResult* res,
                                    gpointer self)
{
	__lambda81_ ((TubaWidgetsScheduledStatus*) self, source_object, res);
	g_object_unref (self);
}

static void
tuba_widgets_scheduled_status_on_delete (TubaWidgetsScheduledStatus* self)
{
	const gchar* _tmp0_ = NULL;
	gchar* title = NULL;
	gchar* _tmp1_;
	TubaApplication* _tmp2_;
	TubaApplicationQuestionText _tmp3_ = {0};
	TubaApplication* _tmp4_;
	TubaDialogsMainWindow* _tmp5_;
	TubaDialogsMainWindow* _tmp6_;
	TubaApplicationQuestionButtons _tmp7_ = {0};
	g_return_if_fail (self != NULL);
	if (!self->priv->_draft) {
		_tmp0_ = _ ("Delete Scheduled Post?");
	} else {
		_tmp0_ = _ ("Delete Draft Post?");
	}
	_tmp1_ = g_strdup (_tmp0_);
	title = _tmp1_;
	_tmp2_ = tuba_app;
	_g_free0 (_tmp3_.text);
	_tmp3_.text = title;
	_tmp3_.use_markup = FALSE;
	_tmp4_ = tuba_app;
	_tmp5_ = tuba_application_get_main_window (_tmp4_);
	_tmp6_ = _tmp5_;
	tuba_application_question_button_destroy (&_tmp7_.yes);
	_tmp7_.yes = (TubaApplicationQuestionButton) {_ ("Delete"), ADW_RESPONSE_DESTRUCTIVE};
	tuba_application_question_button_destroy (&_tmp7_.no);
	_tmp7_.no = (TubaApplicationQuestionButton) {_ ("Cancel"), ADW_RESPONSE_DEFAULT};
	tuba_application_question (_tmp2_, &_tmp3_, NULL, (GtkWidget*) _tmp6_, &_tmp7_, NULL, FALSE, ___lambda81__gasync_ready_callback, g_object_ref (self));
	_g_free0 (title);
}

static void
tuba_widgets_scheduled_status_delete_status_data_free (gpointer _data)
{
	TubaWidgetsScheduledStatusDeleteStatusData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaWidgetsScheduledStatusDeleteStatusData, _data_);
}

static void
tuba_widgets_scheduled_status_delete_status (TubaWidgetsScheduledStatus* self,
                                             GAsyncReadyCallback _callback_,
                                             gpointer _user_data_)
{
	TubaWidgetsScheduledStatusDeleteStatusData* _data_;
	TubaWidgetsScheduledStatus* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (TubaWidgetsScheduledStatusDeleteStatusData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_widgets_scheduled_status_delete_status_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	tuba_widgets_scheduled_status_delete_status_co (_data_);
}

static void
tuba_widgets_scheduled_status_delete_status_finish (TubaWidgetsScheduledStatus* self,
                                                    GAsyncResult* _res_)
{
	TubaWidgetsScheduledStatusDeleteStatusData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
tuba_widgets_scheduled_status_delete_status_ready (GObject* source_object,
                                                   GAsyncResult* _res_,
                                                   gpointer _user_data_)
{
	TubaWidgetsScheduledStatusDeleteStatusData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_widgets_scheduled_status_delete_status_co (_data_);
}

static gboolean
tuba_widgets_scheduled_status_delete_status_co (TubaWidgetsScheduledStatusDeleteStatusData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = _data_->self->priv->bound_scheduled_status;
	_data_->_tmp1_ = tuba_api_scheduled_status_get_id (_data_->_tmp0_);
	_data_->_tmp2_ = _data_->_tmp1_;
	_data_->_tmp3_ = string_to_string (_data_->_tmp2_);
	_data_->_tmp4_ = g_strconcat ("/api/v1/scheduled_statuses/", _data_->_tmp3_, NULL);
	_data_->_tmp5_ = _data_->_tmp4_;
	_data_->_tmp6_ = tuba_accounts;
	_data_->_tmp7_ = tuba_account_store_get_active (_data_->_tmp6_);
	_data_->_tmp8_ = _data_->_tmp7_;
	_data_->_tmp9_ = _g_object_ref0 (_data_->_tmp8_);
	_data_->_tmp10_ = NULL;
	_data_->_tmp10_ = tuba_request_v2_new (_data_->_tmp5_, TUBA_REQUEST_V2_METHOD_DELETE);
	tuba_request_v2_set_account (_data_->_tmp10_, _data_->_tmp9_);
	_g_object_unref0 (_data_->_tmp9_);
	_data_->_tmp11_ = _data_->_tmp10_;
	_g_free0 (_data_->_tmp5_);
	_data_->req = _data_->_tmp11_;
	{
		_data_->_state_ = 1;
		tuba_request_v2_exec (_data_->req, tuba_widgets_scheduled_status_delete_status_ready, _data_);
		return FALSE;
		_state_1:
		_data_->_tmp12_ = tuba_request_v2_exec_finish (_data_->req, _data_->_res_, NULL, &_data_->_inner_error0_);
		_data_->_tmp13_ = _data_->_tmp12_;
		_g_object_unref0 (_data_->_tmp13_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_data_->_tmp14_ = _data_->self->priv->bound_scheduled_status;
		_data_->_tmp15_ = tuba_api_scheduled_status_get_id (_data_->_tmp14_);
		_data_->_tmp16_ = _data_->_tmp15_;
		g_signal_emit (_data_->self, tuba_widgets_scheduled_status_signals[TUBA_WIDGETS_SCHEDULED_STATUS_DELETED_SIGNAL], 0, _data_->_tmp16_);
		_data_->_tmp17_ = tuba_widgets_scheduled_status_get_is_inline (_data_->self);
		_data_->_tmp18_ = _data_->_tmp17_;
		if (_data_->_tmp18_) {
			_data_->_tmp19_ = tuba_app;
			g_signal_emit_by_name (_data_->_tmp19_, "refresh-scheduled-statuses");
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp20_ = _data_->e;
		_data_->_tmp21_ = g_strdup_printf ("%i", _data_->_tmp20_->code);
		_data_->_tmp22_ = _data_->_tmp21_;
		_data_->_tmp23_ = _data_->e;
		_data_->_tmp24_ = _data_->_tmp23_->message;
		_data_->_tmp25_ = string_to_string (_data_->_tmp24_);
		_data_->_tmp26_ = g_strconcat ("Error while deleting scheduled status: ", _data_->_tmp22_, " ", _data_->_tmp25_, NULL);
		_data_->_tmp27_ = _data_->_tmp26_;
		g_warning ("ScheduledStatus.vala:273: %s", _data_->_tmp27_);
		_g_free0 (_data_->_tmp27_);
		_g_free0 (_data_->_tmp22_);
		_data_->_tmp28_ = tuba_app;
		_data_->_tmp29_ = _data_->e;
		_data_->_tmp30_ = _data_->_tmp29_->message;
		g_signal_emit_by_name (_data_->_tmp28_, "toast", _data_->_tmp30_, (guint) 0, NULL, NULL, NULL);
		_g_error_free0 (_data_->e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_g_object_unref0 (_data_->req);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_g_object_unref0 (_data_->req);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
tuba_widgets_scheduled_status_on_activated (TubaWidgetsScheduledStatus* self)
{
	gboolean _tmp0_ = FALSE;
	gboolean _tmp2_;
	gboolean _tmp3_;
	g_return_if_fail (self != NULL);
	if (!self->priv->_draft) {
		_tmp0_ = TRUE;
	} else {
		TubaWidgetsStatus* _tmp1_;
		_tmp1_ = self->priv->status_widget;
		_tmp0_ = _tmp1_ == NULL;
	}
	if (_tmp0_) {
		return;
	}
	_tmp2_ = tuba_widgets_scheduled_status_get_is_inline (self);
	_tmp3_ = _tmp2_;
	if (_tmp3_) {
		g_signal_emit (self, tuba_widgets_scheduled_status_signals[TUBA_WIDGETS_SCHEDULED_STATUS_INLINE_CLICKED_SIGNAL], 0);
		return;
	}
	tuba_widgets_scheduled_status_compose_draft (self);
}

static void
_tuba_widgets_scheduled_status_on_draft_posted_tuba_dialogs_composer_dialog_success_callback (TubaAPIStatus* cb_status,
                                                                                              gpointer self)
{
	tuba_widgets_scheduled_status_on_draft_posted ((TubaWidgetsScheduledStatus*) self, cb_status);
}

void
tuba_widgets_scheduled_status_compose_draft (TubaWidgetsScheduledStatus* self)
{
	TubaAPIScheduledStatus* _tmp0_;
	TubaAPIPoll* _tmp1_;
	TubaDialogsComposerDialog* _tmp2_;
	TubaDialogsComposerDialog* _tmp3_;
	g_return_if_fail (self != NULL);
	if (!self->priv->_draft) {
		return;
	}
	_tmp0_ = self->priv->bound_scheduled_status;
	_tmp1_ = self->priv->status_poll;
	_tmp2_ = tuba_dialogs_composer_dialog_new_from_scheduled (_tmp0_, TRUE, _tmp1_, _tuba_widgets_scheduled_status_on_draft_posted_tuba_dialogs_composer_dialog_success_callback, g_object_ref (self), g_object_unref);
	g_object_ref_sink (_tmp2_);
	_tmp3_ = _tmp2_;
	_g_object_unref0 (_tmp3_);
}

static void
tuba_widgets_scheduled_status_on_draft_posted (TubaWidgetsScheduledStatus* self,
                                               TubaAPIStatus* x)
{
	g_return_if_fail (self != NULL);
	if (self->priv->_draft) {
		tuba_widgets_scheduled_status_delete_status (self, NULL, NULL);
	}
}

static void
_tuba_widgets_scheduled_status_on_edited_tuba_dialogs_composer_dialog_success_callback (TubaAPIStatus* cb_status,
                                                                                        gpointer self)
{
	tuba_widgets_scheduled_status_on_edited ((TubaWidgetsScheduledStatus*) self, cb_status);
}

static void
tuba_widgets_scheduled_status_on_edit (TubaWidgetsScheduledStatus* self)
{
	TubaAPIScheduledStatus* _tmp0_;
	TubaAPIPoll* _tmp1_;
	TubaDialogsComposerDialog* _tmp2_;
	TubaDialogsComposerDialog* _tmp3_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->bound_scheduled_status;
	_tmp1_ = self->priv->status_poll;
	_tmp2_ = tuba_dialogs_composer_dialog_new_from_scheduled (_tmp0_, FALSE, _tmp1_, _tuba_widgets_scheduled_status_on_edited_tuba_dialogs_composer_dialog_success_callback, g_object_ref (self), g_object_unref);
	g_object_ref_sink (_tmp2_);
	_tmp3_ = _tmp2_;
	_g_object_unref0 (_tmp3_);
}

static void
tuba_widgets_scheduled_status_on_edited (TubaWidgetsScheduledStatus* self,
                                         TubaAPIStatus* x)
{
	g_return_if_fail (self != NULL);
	g_signal_emit (self, tuba_widgets_scheduled_status_signals[TUBA_WIDGETS_SCHEDULED_STATUS_REFRESH_SIGNAL], 0);
}

gboolean
tuba_widgets_scheduled_status_get_draft (TubaWidgetsScheduledStatus* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_draft;
	return result;
}

void
tuba_widgets_scheduled_status_set_draft (TubaWidgetsScheduledStatus* self,
                                         gboolean value)
{
	GtkButton* _tmp0_;
	GtkButton* _tmp1_;
	GtkLabel* _tmp2_;
	g_return_if_fail (self != NULL);
	self->priv->_draft = value;
	_tmp0_ = self->priv->to_draft_button;
	_tmp1_ = self->priv->reschedule_button;
	gtk_widget_set_visible ((GtkWidget*) _tmp1_, !value);
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, !value);
	_tmp2_ = self->priv->schedule_label;
	gtk_label_set_label (_tmp2_, _ ("Draft"));
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) self, value);
	g_object_notify_by_pspec ((GObject *) self, tuba_widgets_scheduled_status_properties[TUBA_WIDGETS_SCHEDULED_STATUS_DRAFT_PROPERTY]);
}

gboolean
tuba_widgets_scheduled_status_get_is_inline (TubaWidgetsScheduledStatus* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_is_inline;
	return result;
}

void
tuba_widgets_scheduled_status_set_is_inline (TubaWidgetsScheduledStatus* self,
                                             gboolean value)
{
	GtkSeparator* _tmp0_;
	GtkBox* _tmp1_;
	g_return_if_fail (self != NULL);
	self->priv->_is_inline = value;
	_tmp0_ = self->priv->separator;
	_tmp1_ = self->priv->action_box;
	gtk_widget_set_visible ((GtkWidget*) _tmp1_, !value);
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, !value);
	g_object_notify_by_pspec ((GObject *) self, tuba_widgets_scheduled_status_properties[TUBA_WIDGETS_SCHEDULED_STATUS_IS_INLINE_PROPERTY]);
}

static void
_tuba_widgets_scheduled_status_reschedule_dialog_on_schedule_picked_tuba_dialogs_schedule_schedule_picked (TubaDialogsSchedule* _sender,
                                                                                                           const gchar* iso8601,
                                                                                                           gpointer self)
{
	tuba_widgets_scheduled_status_reschedule_dialog_on_schedule_picked ((TubaWidgetsScheduledStatusRescheduleDialog*) self, iso8601);
}

static void
_tuba_widgets_scheduled_status_reschedule_dialog_on_cancel_tuba_dialogs_schedule_cancelled (TubaDialogsSchedule* _sender,
                                                                                            gpointer self)
{
	tuba_widgets_scheduled_status_reschedule_dialog_on_cancel ((TubaWidgetsScheduledStatusRescheduleDialog*) self);
}

static TubaWidgetsScheduledStatusRescheduleDialog*
tuba_widgets_scheduled_status_reschedule_dialog_construct (GType object_type,
                                                           const gchar* iso8601)
{
	TubaWidgetsScheduledStatusRescheduleDialog * self = NULL;
	TubaDialogsSchedule* schedule_page = NULL;
	TubaDialogsSchedule* _tmp0_ = NULL;
	AdwNavigationView* navigation_view = NULL;
	AdwNavigationView* _tmp1_;
	g_return_val_if_fail (iso8601 != NULL, NULL);
	self = (TubaWidgetsScheduledStatusRescheduleDialog*) g_object_new (object_type, NULL);
	adw_dialog_set_follows_content_size ((AdwDialog*) self, TRUE);
	_tmp0_ = tuba_dialogs_schedule_new (iso8601, _ ("Reschedule"));
	tuba_dialogs_schedule_set_can_cancel (_tmp0_, TRUE);
	g_object_ref_sink (_tmp0_);
	schedule_page = _tmp0_;
	g_signal_connect_object (schedule_page, "schedule-picked", (GCallback) _tuba_widgets_scheduled_status_reschedule_dialog_on_schedule_picked_tuba_dialogs_schedule_schedule_picked, self, 0);
	g_signal_connect_object (schedule_page, "cancelled", (GCallback) _tuba_widgets_scheduled_status_reschedule_dialog_on_cancel_tuba_dialogs_schedule_cancelled, self, 0);
	_tmp1_ = (AdwNavigationView*) adw_navigation_view_new ();
	g_object_ref_sink (_tmp1_);
	navigation_view = _tmp1_;
	adw_navigation_page_set_title ((AdwNavigationPage*) schedule_page, _ ("Reschedule Post"));
	adw_dialog_set_title ((AdwDialog*) self, _ ("Reschedule Post"));
	adw_navigation_view_add (navigation_view, (AdwNavigationPage*) schedule_page);
	adw_dialog_set_child ((AdwDialog*) self, (GtkWidget*) navigation_view);
	_g_object_unref0 (navigation_view);
	_g_object_unref0 (schedule_page);
	return self;
}

static TubaWidgetsScheduledStatusRescheduleDialog*
tuba_widgets_scheduled_status_reschedule_dialog_new (const gchar* iso8601)
{
	return tuba_widgets_scheduled_status_reschedule_dialog_construct (TUBA_WIDGETS_SCHEDULED_STATUS_TYPE_RESCHEDULE_DIALOG, iso8601);
}

static void
tuba_widgets_scheduled_status_reschedule_dialog_on_cancel (TubaWidgetsScheduledStatusRescheduleDialog* self)
{
	g_return_if_fail (self != NULL);
	adw_dialog_force_close ((AdwDialog*) self);
}

static void
tuba_widgets_scheduled_status_reschedule_dialog_on_schedule_picked (TubaWidgetsScheduledStatusRescheduleDialog* self,
                                                                    const gchar* iso8601)
{
	g_return_if_fail (self != NULL);
	g_return_if_fail (iso8601 != NULL);
	g_signal_emit (self, tuba_widgets_scheduled_status_reschedule_dialog_signals[TUBA_WIDGETS_SCHEDULED_STATUS_RESCHEDULE_DIALOG_SCHEDULE_PICKED_SIGNAL], 0, iso8601);
	adw_dialog_force_close ((AdwDialog*) self);
}

static void
tuba_widgets_scheduled_status_reschedule_dialog_class_init (TubaWidgetsScheduledStatusRescheduleDialogClass * klass,
                                                            gpointer klass_data)
{
	tuba_widgets_scheduled_status_reschedule_dialog_parent_class = g_type_class_peek_parent (klass);
	tuba_widgets_scheduled_status_reschedule_dialog_signals[TUBA_WIDGETS_SCHEDULED_STATUS_RESCHEDULE_DIALOG_SCHEDULE_PICKED_SIGNAL] = g_signal_new ("schedule-picked", TUBA_WIDGETS_SCHEDULED_STATUS_TYPE_RESCHEDULE_DIALOG, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
}

static void
tuba_widgets_scheduled_status_reschedule_dialog_instance_init (TubaWidgetsScheduledStatusRescheduleDialog * self,
                                                               gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
tuba_widgets_scheduled_status_reschedule_dialog_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaWidgetsScheduledStatusRescheduleDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_widgets_scheduled_status_reschedule_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaWidgetsScheduledStatusRescheduleDialog), 0, (GInstanceInitFunc) tuba_widgets_scheduled_status_reschedule_dialog_instance_init, NULL };
	GType tuba_widgets_scheduled_status_reschedule_dialog_type_id;
	tuba_widgets_scheduled_status_reschedule_dialog_type_id = g_type_register_static (adw_dialog_get_type (), "TubaWidgetsScheduledStatusRescheduleDialog", &g_define_type_info, G_TYPE_FLAG_NONE);
	return tuba_widgets_scheduled_status_reschedule_dialog_type_id;
}

static GType
tuba_widgets_scheduled_status_reschedule_dialog_get_type (void)
{
	static GType tuba_widgets_scheduled_status_reschedule_dialog_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_widgets_scheduled_status_reschedule_dialog_type_id__once)) {
		GType tuba_widgets_scheduled_status_reschedule_dialog_type_id;
		tuba_widgets_scheduled_status_reschedule_dialog_type_id = tuba_widgets_scheduled_status_reschedule_dialog_get_type_once ();
		g_once_init_leave_pointer (&tuba_widgets_scheduled_status_reschedule_dialog_type_id__once, tuba_widgets_scheduled_status_reschedule_dialog_type_id);
	}
	return tuba_widgets_scheduled_status_reschedule_dialog_type_id__once;
}

static void
_tuba_widgets_scheduled_status_on_edit_gtk_button_clicked (GtkButton* _sender,
                                                           gpointer self)
{
	tuba_widgets_scheduled_status_on_edit ((TubaWidgetsScheduledStatus*) self);
}

static void
_tuba_widgets_scheduled_status_on_reschedule_gtk_button_clicked (GtkButton* _sender,
                                                                 gpointer self)
{
	tuba_widgets_scheduled_status_on_reschedule ((TubaWidgetsScheduledStatus*) self);
}

static void
_tuba_widgets_scheduled_status_on_convert_to_draft_gtk_button_clicked (GtkButton* _sender,
                                                                       gpointer self)
{
	tuba_widgets_scheduled_status_on_convert_to_draft ((TubaWidgetsScheduledStatus*) self);
}

static void
_tuba_widgets_scheduled_status_on_delete_gtk_button_clicked (GtkButton* _sender,
                                                             gpointer self)
{
	tuba_widgets_scheduled_status_on_delete ((TubaWidgetsScheduledStatus*) self);
}

static void
_tuba_widgets_scheduled_status_on_activated_tuba_widgets_scheduled_status_open (TubaWidgetsScheduledStatus* _sender,
                                                                                gpointer self)
{
	tuba_widgets_scheduled_status_on_activated ((TubaWidgetsScheduledStatus*) self);
}

static GObject *
tuba_widgets_scheduled_status_constructor (GType type,
                                           guint n_construct_properties,
                                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaWidgetsScheduledStatus * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar** _tmp3_;
	gchar** _tmp4_;
	gint _tmp4__length1;
	GtkBox* _tmp5_;
	gint _tmp6_ = 0;
	GtkBox* _tmp7_ = NULL;
	GtkLabel* _tmp8_ = NULL;
	GtkBox* _tmp9_;
	GtkLabel* _tmp10_;
	GtkBox* actions_box = NULL;
	GtkBox* _tmp11_;
	gchar* _tmp12_;
	gchar** _tmp13_;
	gchar* _tmp14_;
	GtkButton* _tmp15_ = NULL;
	GtkButton* _tmp16_;
	GtkBox* _tmp17_;
	GtkButton* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar** _tmp21_;
	GtkButton* _tmp22_ = NULL;
	GtkButton* _tmp23_;
	GtkBox* _tmp24_;
	GtkButton* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	gchar** _tmp28_;
	GtkButton* _tmp29_ = NULL;
	GtkButton* _tmp30_;
	GtkBox* _tmp31_;
	GtkButton* _tmp32_;
	GtkButton* delete_button = NULL;
	gchar* _tmp33_;
	gchar* _tmp34_;
	gchar** _tmp35_;
	gchar* _tmp36_;
	GtkButton* _tmp37_ = NULL;
	GtkButton* _tmp38_;
	GtkBox* _tmp39_;
	GtkButton* _tmp40_;
	GtkBox* _tmp41_;
	GtkBox* _tmp42_;
	GtkBox* _tmp43_;
	GtkBox* _tmp44_;
	GtkSeparator* _tmp45_;
	GtkBox* _tmp46_;
	GtkSeparator* _tmp47_;
	GtkBox* _tmp48_;
	parent_class = G_OBJECT_CLASS (tuba_widgets_scheduled_status_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatus);
	gtk_widget_set_focusable ((GtkWidget*) self, TRUE);
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) self, FALSE);
	_tmp0_ = g_strdup ("card-spacing");
	_tmp1_ = g_strdup ("card");
	_tmp2_ = g_strdup ("no-padding");
	_tmp3_ = g_new0 (gchar*, 3 + 1);
	_tmp3_[0] = _tmp0_;
	_tmp3_[1] = _tmp1_;
	_tmp3_[2] = _tmp2_;
	_tmp4_ = _tmp3_;
	_tmp4__length1 = 3;
	gtk_widget_set_css_classes ((GtkWidget*) self, _tmp4_);
	_tmp4_ = (_vala_array_free (_tmp4_, _tmp4__length1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_overflow ((GtkWidget*) self, GTK_OVERFLOW_HIDDEN);
	_tmp5_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
	g_object_ref_sink (_tmp5_);
	_g_object_unref0 (self->priv->content_box);
	self->priv->content_box = _tmp5_;
	_tmp6_ = 6;
	_tmp7_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp7_, _tmp6_);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp7_, _tmp6_);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp7_, _tmp6_);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp7_, _tmp6_);
	g_object_ref_sink (_tmp7_);
	_g_object_unref0 (self->priv->action_box);
	self->priv->action_box = _tmp7_;
	_tmp8_ = (GtkLabel*) gtk_label_new ("");
	gtk_label_set_wrap (_tmp8_, TRUE);
	gtk_label_set_wrap_mode (_tmp8_, PANGO_WRAP_WORD_CHAR);
	gtk_label_set_xalign (_tmp8_, 0.0f);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp8_, TRUE);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp8_, 6);
	g_object_ref_sink (_tmp8_);
	_g_object_unref0 (self->priv->schedule_label);
	self->priv->schedule_label = _tmp8_;
	_tmp9_ = self->priv->action_box;
	_tmp10_ = self->priv->schedule_label;
	gtk_box_append (_tmp9_, (GtkWidget*) _tmp10_);
	_tmp11_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
	g_object_ref_sink (_tmp11_);
	actions_box = _tmp11_;
	_tmp12_ = g_strdup ("flat");
	_tmp13_ = g_new0 (gchar*, 1 + 1);
	_tmp13_[0] = _tmp12_;
	_tmp14_ = g_strdup (_ ("Edit"));
	_tmp15_ = (GtkButton*) gtk_button_new_from_icon_name ("document-edit-symbolic");
	gtk_widget_set_css_classes ((GtkWidget*) _tmp15_, _tmp13_);
	_tmp13_ = (_vala_array_free (_tmp13_, 1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp15_, _tmp14_);
	_g_free0 (_tmp14_);
	gtk_widget_set_valign ((GtkWidget*) _tmp15_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp15_);
	_g_object_unref0 (self->priv->edit_button);
	self->priv->edit_button = _tmp15_;
	_tmp16_ = self->priv->edit_button;
	g_signal_connect_object (_tmp16_, "clicked", (GCallback) _tuba_widgets_scheduled_status_on_edit_gtk_button_clicked, self, 0);
	_tmp17_ = actions_box;
	_tmp18_ = self->priv->edit_button;
	gtk_box_append (_tmp17_, (GtkWidget*) _tmp18_);
	_tmp19_ = g_strdup (_ ("Reschedule"));
	_tmp20_ = g_strdup ("flat");
	_tmp21_ = g_new0 (gchar*, 1 + 1);
	_tmp21_[0] = _tmp20_;
	_tmp22_ = (GtkButton*) gtk_button_new_from_icon_name ("tuba-clock-alt-symbolic");
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp22_, _tmp19_);
	_g_free0 (_tmp19_);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp22_, _tmp21_);
	_tmp21_ = (_vala_array_free (_tmp21_, 1, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp22_);
	_g_object_unref0 (self->priv->reschedule_button);
	self->priv->reschedule_button = _tmp22_;
	_tmp23_ = self->priv->reschedule_button;
	g_signal_connect_object (_tmp23_, "clicked", (GCallback) _tuba_widgets_scheduled_status_on_reschedule_gtk_button_clicked, self, 0);
	_tmp24_ = actions_box;
	_tmp25_ = self->priv->reschedule_button;
	gtk_box_append (_tmp24_, (GtkWidget*) _tmp25_);
	_tmp26_ = g_strdup (_ ("Convert into a draft"));
	_tmp27_ = g_strdup ("flat");
	_tmp28_ = g_new0 (gchar*, 1 + 1);
	_tmp28_[0] = _tmp27_;
	_tmp29_ = (GtkButton*) gtk_button_new_from_icon_name ("tuba-archive-symbolic");
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp29_, _tmp26_);
	_g_free0 (_tmp26_);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp29_, _tmp28_);
	_tmp28_ = (_vala_array_free (_tmp28_, 1, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp29_);
	_g_object_unref0 (self->priv->to_draft_button);
	self->priv->to_draft_button = _tmp29_;
	_tmp30_ = self->priv->to_draft_button;
	g_signal_connect_object (_tmp30_, "clicked", (GCallback) _tuba_widgets_scheduled_status_on_convert_to_draft_gtk_button_clicked, self, 0);
	_tmp31_ = actions_box;
	_tmp32_ = self->priv->to_draft_button;
	gtk_box_append (_tmp31_, (GtkWidget*) _tmp32_);
	_tmp33_ = g_strdup ("flat");
	_tmp34_ = g_strdup ("error");
	_tmp35_ = g_new0 (gchar*, 2 + 1);
	_tmp35_[0] = _tmp33_;
	_tmp35_[1] = _tmp34_;
	_tmp36_ = g_strdup (_ ("Delete"));
	_tmp37_ = (GtkButton*) gtk_button_new_from_icon_name ("user-trash-symbolic");
	gtk_widget_set_css_classes ((GtkWidget*) _tmp37_, _tmp35_);
	_tmp35_ = (_vala_array_free (_tmp35_, 2, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp37_, _tmp36_);
	_g_free0 (_tmp36_);
	gtk_widget_set_valign ((GtkWidget*) _tmp37_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp37_);
	delete_button = _tmp37_;
	_tmp38_ = delete_button;
	g_signal_connect_object (_tmp38_, "clicked", (GCallback) _tuba_widgets_scheduled_status_on_delete_gtk_button_clicked, self, 0);
	_tmp39_ = actions_box;
	_tmp40_ = delete_button;
	gtk_box_append (_tmp39_, (GtkWidget*) _tmp40_);
	_tmp41_ = self->priv->action_box;
	_tmp42_ = actions_box;
	gtk_box_append (_tmp41_, (GtkWidget*) _tmp42_);
	_tmp43_ = self->priv->content_box;
	_tmp44_ = self->priv->action_box;
	gtk_box_append (_tmp43_, (GtkWidget*) _tmp44_);
	_tmp45_ = (GtkSeparator*) gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
	g_object_ref_sink (_tmp45_);
	_g_object_unref0 (self->priv->separator);
	self->priv->separator = _tmp45_;
	_tmp46_ = self->priv->content_box;
	_tmp47_ = self->priv->separator;
	gtk_box_append (_tmp46_, (GtkWidget*) _tmp47_);
	_tmp48_ = self->priv->content_box;
	gtk_list_box_row_set_child ((GtkListBoxRow*) self, (GtkWidget*) _tmp48_);
	g_signal_connect_object (self, "open", (GCallback) _tuba_widgets_scheduled_status_on_activated_tuba_widgets_scheduled_status_open, self, 0);
	_g_object_unref0 (delete_button);
	_g_object_unref0 (actions_box);
	return obj;
}

static void
tuba_widgets_scheduled_status_class_init (TubaWidgetsScheduledStatusClass * klass,
                                          gpointer klass_data)
{
	tuba_widgets_scheduled_status_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaWidgetsScheduledStatus_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_widgets_scheduled_status_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_widgets_scheduled_status_set_property;
	G_OBJECT_CLASS (klass)->constructor = tuba_widgets_scheduled_status_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_widgets_scheduled_status_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_WIDGETS_SCHEDULED_STATUS_DRAFT_PROPERTY, tuba_widgets_scheduled_status_properties[TUBA_WIDGETS_SCHEDULED_STATUS_DRAFT_PROPERTY] = g_param_spec_boolean ("draft", "draft", "draft", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_WIDGETS_SCHEDULED_STATUS_IS_INLINE_PROPERTY, tuba_widgets_scheduled_status_properties[TUBA_WIDGETS_SCHEDULED_STATUS_IS_INLINE_PROPERTY] = g_param_spec_boolean ("is-inline", "is-inline", "is-inline", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	tuba_widgets_scheduled_status_signals[TUBA_WIDGETS_SCHEDULED_STATUS_DELETED_SIGNAL] = g_signal_new ("deleted", TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	tuba_widgets_scheduled_status_signals[TUBA_WIDGETS_SCHEDULED_STATUS_REFRESH_SIGNAL] = g_signal_new ("refresh", TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	tuba_widgets_scheduled_status_signals[TUBA_WIDGETS_SCHEDULED_STATUS_OPEN_SIGNAL] = g_signal_new ("open", TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	tuba_widgets_scheduled_status_signals[TUBA_WIDGETS_SCHEDULED_STATUS_INLINE_CLICKED_SIGNAL] = g_signal_new ("inline-clicked", TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}

static void
tuba_widgets_scheduled_status_instance_init (TubaWidgetsScheduledStatus * self,
                                             gpointer klass)
{
	self->priv = tuba_widgets_scheduled_status_get_instance_private (self);
	self->priv->_draft = FALSE;
	self->priv->_is_inline = FALSE;
	self->priv->status_widget = NULL;
	self->priv->status_poll = NULL;
}

static void
tuba_widgets_scheduled_status_finalize (GObject * obj)
{
	TubaWidgetsScheduledStatus * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatus);
	_g_object_unref0 (self->priv->reschedule_button);
	_g_object_unref0 (self->priv->to_draft_button);
	_g_object_unref0 (self->priv->edit_button);
	_g_object_unref0 (self->priv->content_box);
	_g_object_unref0 (self->priv->schedule_label);
	_g_object_unref0 (self->priv->action_box);
	_g_object_unref0 (self->priv->separator);
	_g_object_unref0 (self->priv->bound_scheduled_status);
	_g_object_unref0 (self->priv->status_widget);
	_g_object_unref0 (self->priv->status_poll);
	G_OBJECT_CLASS (tuba_widgets_scheduled_status_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_widgets_scheduled_status_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaWidgetsScheduledStatusClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_widgets_scheduled_status_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaWidgetsScheduledStatus), 0, (GInstanceInitFunc) tuba_widgets_scheduled_status_instance_init, NULL };
	GType tuba_widgets_scheduled_status_type_id;
	tuba_widgets_scheduled_status_type_id = g_type_register_static (gtk_list_box_row_get_type (), "TubaWidgetsScheduledStatus", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaWidgetsScheduledStatus_private_offset = g_type_add_instance_private (tuba_widgets_scheduled_status_type_id, sizeof (TubaWidgetsScheduledStatusPrivate));
	return tuba_widgets_scheduled_status_type_id;
}

GType
tuba_widgets_scheduled_status_get_type (void)
{
	static GType tuba_widgets_scheduled_status_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_widgets_scheduled_status_type_id__once)) {
		GType tuba_widgets_scheduled_status_type_id;
		tuba_widgets_scheduled_status_type_id = tuba_widgets_scheduled_status_get_type_once ();
		g_once_init_leave_pointer (&tuba_widgets_scheduled_status_type_id__once, tuba_widgets_scheduled_status_type_id);
	}
	return tuba_widgets_scheduled_status_type_id__once;
}

static void
_vala_tuba_widgets_scheduled_status_get_property (GObject * object,
                                                  guint property_id,
                                                  GValue * value,
                                                  GParamSpec * pspec)
{
	TubaWidgetsScheduledStatus * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatus);
	switch (property_id) {
		case TUBA_WIDGETS_SCHEDULED_STATUS_DRAFT_PROPERTY:
		g_value_set_boolean (value, tuba_widgets_scheduled_status_get_draft (self));
		break;
		case TUBA_WIDGETS_SCHEDULED_STATUS_IS_INLINE_PROPERTY:
		g_value_set_boolean (value, tuba_widgets_scheduled_status_get_is_inline (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_widgets_scheduled_status_set_property (GObject * object,
                                                  guint property_id,
                                                  const GValue * value,
                                                  GParamSpec * pspec)
{
	TubaWidgetsScheduledStatus * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatus);
	switch (property_id) {
		case TUBA_WIDGETS_SCHEDULED_STATUS_DRAFT_PROPERTY:
		tuba_widgets_scheduled_status_set_draft (self, g_value_get_boolean (value));
		break;
		case TUBA_WIDGETS_SCHEDULED_STATUS_IS_INLINE_PROPERTY:
		tuba_widgets_scheduled_status_set_is_inline (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

